#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsMarketingCampaignDecisionModel(object):

    def __init__(self):
        self._business_type = None
        self._market_types = None
        self._mkt_obj_id = None
        self._mkt_obj_type = None
        self._request_id = None

    @property
    def business_type(self):
        return self._business_type

    @business_type.setter
    def business_type(self, value):
        self._business_type = value
    @property
    def market_types(self):
        return self._market_types

    @market_types.setter
    def market_types(self, value):
        if isinstance(value, list):
            self._market_types = list()
            for i in value:
                self._market_types.append(i)
    @property
    def mkt_obj_id(self):
        return self._mkt_obj_id

    @mkt_obj_id.setter
    def mkt_obj_id(self, value):
        self._mkt_obj_id = value
    @property
    def mkt_obj_type(self):
        return self._mkt_obj_type

    @mkt_obj_type.setter
    def mkt_obj_type(self, value):
        self._mkt_obj_type = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_type:
            if hasattr(self.business_type, 'to_alipay_dict'):
                params['business_type'] = self.business_type.to_alipay_dict()
            else:
                params['business_type'] = self.business_type
        if self.market_types:
            if isinstance(self.market_types, list):
                for i in range(0, len(self.market_types)):
                    element = self.market_types[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.market_types[i] = element.to_alipay_dict()
            if hasattr(self.market_types, 'to_alipay_dict'):
                params['market_types'] = self.market_types.to_alipay_dict()
            else:
                params['market_types'] = self.market_types
        if self.mkt_obj_id:
            if hasattr(self.mkt_obj_id, 'to_alipay_dict'):
                params['mkt_obj_id'] = self.mkt_obj_id.to_alipay_dict()
            else:
                params['mkt_obj_id'] = self.mkt_obj_id
        if self.mkt_obj_type:
            if hasattr(self.mkt_obj_type, 'to_alipay_dict'):
                params['mkt_obj_type'] = self.mkt_obj_type.to_alipay_dict()
            else:
                params['mkt_obj_type'] = self.mkt_obj_type
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsMarketingCampaignDecisionModel()
        if 'business_type' in d:
            o.business_type = d['business_type']
        if 'market_types' in d:
            o.market_types = d['market_types']
        if 'mkt_obj_id' in d:
            o.mkt_obj_id = d['mkt_obj_id']
        if 'mkt_obj_type' in d:
            o.mkt_obj_type = d['mkt_obj_type']
        if 'request_id' in d:
            o.request_id = d['request_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class QueryUserChargeInstAndAreaInfo(object):

    def __init__(self):
        self._charge_inst = None
        self._charge_inst_name = None
        self._city = None
        self._city_code = None
        self._pay_count = None
        self._pay_date = None
        self._sub_biz_type = None
        self._user_id = None

    @property
    def charge_inst(self):
        return self._charge_inst

    @charge_inst.setter
    def charge_inst(self, value):
        self._charge_inst = value
    @property
    def charge_inst_name(self):
        return self._charge_inst_name

    @charge_inst_name.setter
    def charge_inst_name(self, value):
        self._charge_inst_name = value
    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def pay_count(self):
        return self._pay_count

    @pay_count.setter
    def pay_count(self, value):
        self._pay_count = value
    @property
    def pay_date(self):
        return self._pay_date

    @pay_date.setter
    def pay_date(self, value):
        self._pay_date = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.charge_inst:
            if hasattr(self.charge_inst, 'to_alipay_dict'):
                params['charge_inst'] = self.charge_inst.to_alipay_dict()
            else:
                params['charge_inst'] = self.charge_inst
        if self.charge_inst_name:
            if hasattr(self.charge_inst_name, 'to_alipay_dict'):
                params['charge_inst_name'] = self.charge_inst_name.to_alipay_dict()
            else:
                params['charge_inst_name'] = self.charge_inst_name
        if self.city:
            if hasattr(self.city, 'to_alipay_dict'):
                params['city'] = self.city.to_alipay_dict()
            else:
                params['city'] = self.city
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.pay_count:
            if hasattr(self.pay_count, 'to_alipay_dict'):
                params['pay_count'] = self.pay_count.to_alipay_dict()
            else:
                params['pay_count'] = self.pay_count
        if self.pay_date:
            if hasattr(self.pay_date, 'to_alipay_dict'):
                params['pay_date'] = self.pay_date.to_alipay_dict()
            else:
                params['pay_date'] = self.pay_date
        if self.sub_biz_type:
            if hasattr(self.sub_biz_type, 'to_alipay_dict'):
                params['sub_biz_type'] = self.sub_biz_type.to_alipay_dict()
            else:
                params['sub_biz_type'] = self.sub_biz_type
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = QueryUserChargeInstAndAreaInfo()
        if 'charge_inst' in d:
            o.charge_inst = d['charge_inst']
        if 'charge_inst_name' in d:
            o.charge_inst_name = d['charge_inst_name']
        if 'city' in d:
            o.city = d['city']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'pay_count' in d:
            o.pay_count = d['pay_count']
        if 'pay_date' in d:
            o.pay_date = d['pay_date']
        if 'sub_biz_type' in d:
            o.sub_biz_type = d['sub_biz_type']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.FinanceReceivableResultInfo import FinanceReceivableResultInfo


class AnttechBlockchainFinanceAssetIssueQueryResponse(AlipayResponse):

    def __init__(self):
        super(AnttechBlockchainFinanceAssetIssueQueryResponse, self).__init__()
        self._failed_code = None
        self._failed_desc = None
        self._receivable_result_info = None
        self._status = None

    @property
    def failed_code(self):
        return self._failed_code

    @failed_code.setter
    def failed_code(self, value):
        self._failed_code = value
    @property
    def failed_desc(self):
        return self._failed_desc

    @failed_desc.setter
    def failed_desc(self, value):
        self._failed_desc = value
    @property
    def receivable_result_info(self):
        return self._receivable_result_info

    @receivable_result_info.setter
    def receivable_result_info(self, value):
        if isinstance(value, FinanceReceivableResultInfo):
            self._receivable_result_info = value
        else:
            self._receivable_result_info = FinanceReceivableResultInfo.from_alipay_dict(value)
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AnttechBlockchainFinanceAssetIssueQueryResponse, self).parse_response_content(response_content)
        if 'failed_code' in response:
            self.failed_code = response['failed_code']
        if 'failed_desc' in response:
            self.failed_desc = response['failed_desc']
        if 'receivable_result_info' in response:
            self.receivable_result_info = response['receivable_result_info']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ReceiverInfoVO(object):

    def __init__(self):
        self._area = None
        self._city = None
        self._detail_address = None
        self._mobile = None
        self._name = None
        self._province = None

    @property
    def area(self):
        return self._area

    @area.setter
    def area(self, value):
        self._area = value
    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def detail_address(self):
        return self._detail_address

    @detail_address.setter
    def detail_address(self, value):
        self._detail_address = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def province(self):
        return self._province

    @province.setter
    def province(self, value):
        self._province = value


    def to_alipay_dict(self):
        params = dict()
        if self.area:
            if hasattr(self.area, 'to_alipay_dict'):
                params['area'] = self.area.to_alipay_dict()
            else:
                params['area'] = self.area
        if self.city:
            if hasattr(self.city, 'to_alipay_dict'):
                params['city'] = self.city.to_alipay_dict()
            else:
                params['city'] = self.city
        if self.detail_address:
            if hasattr(self.detail_address, 'to_alipay_dict'):
                params['detail_address'] = self.detail_address.to_alipay_dict()
            else:
                params['detail_address'] = self.detail_address
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.province:
            if hasattr(self.province, 'to_alipay_dict'):
                params['province'] = self.province.to_alipay_dict()
            else:
                params['province'] = self.province
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ReceiverInfoVO()
        if 'area' in d:
            o.area = d['area']
        if 'city' in d:
            o.city = d['city']
        if 'detail_address' in d:
            o.detail_address = d['detail_address']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'name' in d:
            o.name = d['name']
        if 'province' in d:
            o.province = d['province']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayPcreditHuabeiAuthAgreementQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayPcreditHuabeiAuthAgreementQueryResponse, self).__init__()
        self._agreement_name = None
        self._agreement_no = None
        self._agreement_status = None
        self._alipay_user_id = None
        self._auth_scene = None
        self._external_logon_id = None
        self._gmt_sign = None
        self._gmt_unsign = None
        self._out_biz_type = None
        self._out_sign_no = None
        self._rest_freeze_amount = None

    @property
    def agreement_name(self):
        return self._agreement_name

    @agreement_name.setter
    def agreement_name(self, value):
        self._agreement_name = value
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def agreement_status(self):
        return self._agreement_status

    @agreement_status.setter
    def agreement_status(self, value):
        self._agreement_status = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def auth_scene(self):
        return self._auth_scene

    @auth_scene.setter
    def auth_scene(self, value):
        self._auth_scene = value
    @property
    def external_logon_id(self):
        return self._external_logon_id

    @external_logon_id.setter
    def external_logon_id(self, value):
        self._external_logon_id = value
    @property
    def gmt_sign(self):
        return self._gmt_sign

    @gmt_sign.setter
    def gmt_sign(self, value):
        self._gmt_sign = value
    @property
    def gmt_unsign(self):
        return self._gmt_unsign

    @gmt_unsign.setter
    def gmt_unsign(self, value):
        self._gmt_unsign = value
    @property
    def out_biz_type(self):
        return self._out_biz_type

    @out_biz_type.setter
    def out_biz_type(self, value):
        self._out_biz_type = value
    @property
    def out_sign_no(self):
        return self._out_sign_no

    @out_sign_no.setter
    def out_sign_no(self, value):
        self._out_sign_no = value
    @property
    def rest_freeze_amount(self):
        return self._rest_freeze_amount

    @rest_freeze_amount.setter
    def rest_freeze_amount(self, value):
        self._rest_freeze_amount = value

    def parse_response_content(self, response_content):
        response = super(AlipayPcreditHuabeiAuthAgreementQueryResponse, self).parse_response_content(response_content)
        if 'agreement_name' in response:
            self.agreement_name = response['agreement_name']
        if 'agreement_no' in response:
            self.agreement_no = response['agreement_no']
        if 'agreement_status' in response:
            self.agreement_status = response['agreement_status']
        if 'alipay_user_id' in response:
            self.alipay_user_id = response['alipay_user_id']
        if 'auth_scene' in response:
            self.auth_scene = response['auth_scene']
        if 'external_logon_id' in response:
            self.external_logon_id = response['external_logon_id']
        if 'gmt_sign' in response:
            self.gmt_sign = response['gmt_sign']
        if 'gmt_unsign' in response:
            self.gmt_unsign = response['gmt_unsign']
        if 'out_biz_type' in response:
            self.out_biz_type = response['out_biz_type']
        if 'out_sign_no' in response:
            self.out_sign_no = response['out_sign_no']
        if 'rest_freeze_amount' in response:
            self.rest_freeze_amount = response['rest_freeze_amount']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DashBoardMeta(object):

    def __init__(self):
        self._auth_status = None
        self._create_time = None
        self._dashboard_id = None
        self._dashboard_name = None

    @property
    def auth_status(self):
        return self._auth_status

    @auth_status.setter
    def auth_status(self, value):
        self._auth_status = value
    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def dashboard_id(self):
        return self._dashboard_id

    @dashboard_id.setter
    def dashboard_id(self, value):
        self._dashboard_id = value
    @property
    def dashboard_name(self):
        return self._dashboard_name

    @dashboard_name.setter
    def dashboard_name(self, value):
        self._dashboard_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_status:
            if hasattr(self.auth_status, 'to_alipay_dict'):
                params['auth_status'] = self.auth_status.to_alipay_dict()
            else:
                params['auth_status'] = self.auth_status
        if self.create_time:
            if hasattr(self.create_time, 'to_alipay_dict'):
                params['create_time'] = self.create_time.to_alipay_dict()
            else:
                params['create_time'] = self.create_time
        if self.dashboard_id:
            if hasattr(self.dashboard_id, 'to_alipay_dict'):
                params['dashboard_id'] = self.dashboard_id.to_alipay_dict()
            else:
                params['dashboard_id'] = self.dashboard_id
        if self.dashboard_name:
            if hasattr(self.dashboard_name, 'to_alipay_dict'):
                params['dashboard_name'] = self.dashboard_name.to_alipay_dict()
            else:
                params['dashboard_name'] = self.dashboard_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DashBoardMeta()
        if 'auth_status' in d:
            o.auth_status = d['auth_status']
        if 'create_time' in d:
            o.create_time = d['create_time']
        if 'dashboard_id' in d:
            o.dashboard_id = d['dashboard_id']
        if 'dashboard_name' in d:
            o.dashboard_name = d['dashboard_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.GoodsDetail import GoodsDetail


class MybankEcnyTradePayModel(object):

    def __init__(self):
        self._auth_code = None
        self._body = None
        self._extend_params = None
        self._goods_detail = None
        self._merchant_id = None
        self._merchant_order_no = None
        self._operator_id = None
        self._out_trade_no = None
        self._passback_params = None
        self._product_code = None
        self._scene = None
        self._store_id = None
        self._subject = None
        self._terminal_id = None
        self._timeout_express = None
        self._total_amount = None

    @property
    def auth_code(self):
        return self._auth_code

    @auth_code.setter
    def auth_code(self, value):
        self._auth_code = value
    @property
    def body(self):
        return self._body

    @body.setter
    def body(self, value):
        self._body = value
    @property
    def extend_params(self):
        return self._extend_params

    @extend_params.setter
    def extend_params(self, value):
        self._extend_params = value
    @property
    def goods_detail(self):
        return self._goods_detail

    @goods_detail.setter
    def goods_detail(self, value):
        if isinstance(value, list):
            self._goods_detail = list()
            for i in value:
                if isinstance(i, GoodsDetail):
                    self._goods_detail.append(i)
                else:
                    self._goods_detail.append(GoodsDetail.from_alipay_dict(i))
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def merchant_order_no(self):
        return self._merchant_order_no

    @merchant_order_no.setter
    def merchant_order_no(self, value):
        self._merchant_order_no = value
    @property
    def operator_id(self):
        return self._operator_id

    @operator_id.setter
    def operator_id(self, value):
        self._operator_id = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def passback_params(self):
        return self._passback_params

    @passback_params.setter
    def passback_params(self, value):
        self._passback_params = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value
    @property
    def store_id(self):
        return self._store_id

    @store_id.setter
    def store_id(self, value):
        self._store_id = value
    @property
    def subject(self):
        return self._subject

    @subject.setter
    def subject(self, value):
        self._subject = value
    @property
    def terminal_id(self):
        return self._terminal_id

    @terminal_id.setter
    def terminal_id(self, value):
        self._terminal_id = value
    @property
    def timeout_express(self):
        return self._timeout_express

    @timeout_express.setter
    def timeout_express(self, value):
        self._timeout_express = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_code:
            if hasattr(self.auth_code, 'to_alipay_dict'):
                params['auth_code'] = self.auth_code.to_alipay_dict()
            else:
                params['auth_code'] = self.auth_code
        if self.body:
            if hasattr(self.body, 'to_alipay_dict'):
                params['body'] = self.body.to_alipay_dict()
            else:
                params['body'] = self.body
        if self.extend_params:
            if hasattr(self.extend_params, 'to_alipay_dict'):
                params['extend_params'] = self.extend_params.to_alipay_dict()
            else:
                params['extend_params'] = self.extend_params
        if self.goods_detail:
            if isinstance(self.goods_detail, list):
                for i in range(0, len(self.goods_detail)):
                    element = self.goods_detail[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.goods_detail[i] = element.to_alipay_dict()
            if hasattr(self.goods_detail, 'to_alipay_dict'):
                params['goods_detail'] = self.goods_detail.to_alipay_dict()
            else:
                params['goods_detail'] = self.goods_detail
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.merchant_order_no:
            if hasattr(self.merchant_order_no, 'to_alipay_dict'):
                params['merchant_order_no'] = self.merchant_order_no.to_alipay_dict()
            else:
                params['merchant_order_no'] = self.merchant_order_no
        if self.operator_id:
            if hasattr(self.operator_id, 'to_alipay_dict'):
                params['operator_id'] = self.operator_id.to_alipay_dict()
            else:
                params['operator_id'] = self.operator_id
        if self.out_trade_no:
            if hasattr(self.out_trade_no, 'to_alipay_dict'):
                params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
            else:
                params['out_trade_no'] = self.out_trade_no
        if self.passback_params:
            if hasattr(self.passback_params, 'to_alipay_dict'):
                params['passback_params'] = self.passback_params.to_alipay_dict()
            else:
                params['passback_params'] = self.passback_params
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        if self.store_id:
            if hasattr(self.store_id, 'to_alipay_dict'):
                params['store_id'] = self.store_id.to_alipay_dict()
            else:
                params['store_id'] = self.store_id
        if self.subject:
            if hasattr(self.subject, 'to_alipay_dict'):
                params['subject'] = self.subject.to_alipay_dict()
            else:
                params['subject'] = self.subject
        if self.terminal_id:
            if hasattr(self.terminal_id, 'to_alipay_dict'):
                params['terminal_id'] = self.terminal_id.to_alipay_dict()
            else:
                params['terminal_id'] = self.terminal_id
        if self.timeout_express:
            if hasattr(self.timeout_express, 'to_alipay_dict'):
                params['timeout_express'] = self.timeout_express.to_alipay_dict()
            else:
                params['timeout_express'] = self.timeout_express
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankEcnyTradePayModel()
        if 'auth_code' in d:
            o.auth_code = d['auth_code']
        if 'body' in d:
            o.body = d['body']
        if 'extend_params' in d:
            o.extend_params = d['extend_params']
        if 'goods_detail' in d:
            o.goods_detail = d['goods_detail']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'merchant_order_no' in d:
            o.merchant_order_no = d['merchant_order_no']
        if 'operator_id' in d:
            o.operator_id = d['operator_id']
        if 'out_trade_no' in d:
            o.out_trade_no = d['out_trade_no']
        if 'passback_params' in d:
            o.passback_params = d['passback_params']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'scene' in d:
            o.scene = d['scene']
        if 'store_id' in d:
            o.store_id = d['store_id']
        if 'subject' in d:
            o.subject = d['subject']
        if 'terminal_id' in d:
            o.terminal_id = d['terminal_id']
        if 'timeout_express' in d:
            o.timeout_express = d['timeout_express']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayPcreditLoanApplyQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayPcreditLoanApplyQueryResponse, self).__init__()
        self._apply_amt = None
        self._apply_date = None
        self._ar_no = None
        self._cert_no = None
        self._cert_type = None
        self._credit_no = None
        self._daily_int_rate = None
        self._due_date = None
        self._encash_org = None
        self._loan_apply_no = None
        self._need_prepayment_fee = None
        self._payment_dt = None
        self._repay_mode = None
        self._status = None
        self._term = None
        self._term_unit = None
        self._user_name = None

    @property
    def apply_amt(self):
        return self._apply_amt

    @apply_amt.setter
    def apply_amt(self, value):
        self._apply_amt = value
    @property
    def apply_date(self):
        return self._apply_date

    @apply_date.setter
    def apply_date(self, value):
        self._apply_date = value
    @property
    def ar_no(self):
        return self._ar_no

    @ar_no.setter
    def ar_no(self, value):
        self._ar_no = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def credit_no(self):
        return self._credit_no

    @credit_no.setter
    def credit_no(self, value):
        self._credit_no = value
    @property
    def daily_int_rate(self):
        return self._daily_int_rate

    @daily_int_rate.setter
    def daily_int_rate(self, value):
        self._daily_int_rate = value
    @property
    def due_date(self):
        return self._due_date

    @due_date.setter
    def due_date(self, value):
        self._due_date = value
    @property
    def encash_org(self):
        return self._encash_org

    @encash_org.setter
    def encash_org(self, value):
        self._encash_org = value
    @property
    def loan_apply_no(self):
        return self._loan_apply_no

    @loan_apply_no.setter
    def loan_apply_no(self, value):
        self._loan_apply_no = value
    @property
    def need_prepayment_fee(self):
        return self._need_prepayment_fee

    @need_prepayment_fee.setter
    def need_prepayment_fee(self, value):
        self._need_prepayment_fee = value
    @property
    def payment_dt(self):
        return self._payment_dt

    @payment_dt.setter
    def payment_dt(self, value):
        self._payment_dt = value
    @property
    def repay_mode(self):
        return self._repay_mode

    @repay_mode.setter
    def repay_mode(self, value):
        self._repay_mode = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def term(self):
        return self._term

    @term.setter
    def term(self, value):
        self._term = value
    @property
    def term_unit(self):
        return self._term_unit

    @term_unit.setter
    def term_unit(self, value):
        self._term_unit = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value

    def parse_response_content(self, response_content):
        response = super(AlipayPcreditLoanApplyQueryResponse, self).parse_response_content(response_content)
        if 'apply_amt' in response:
            self.apply_amt = response['apply_amt']
        if 'apply_date' in response:
            self.apply_date = response['apply_date']
        if 'ar_no' in response:
            self.ar_no = response['ar_no']
        if 'cert_no' in response:
            self.cert_no = response['cert_no']
        if 'cert_type' in response:
            self.cert_type = response['cert_type']
        if 'credit_no' in response:
            self.credit_no = response['credit_no']
        if 'daily_int_rate' in response:
            self.daily_int_rate = response['daily_int_rate']
        if 'due_date' in response:
            self.due_date = response['due_date']
        if 'encash_org' in response:
            self.encash_org = response['encash_org']
        if 'loan_apply_no' in response:
            self.loan_apply_no = response['loan_apply_no']
        if 'need_prepayment_fee' in response:
            self.need_prepayment_fee = response['need_prepayment_fee']
        if 'payment_dt' in response:
            self.payment_dt = response['payment_dt']
        if 'repay_mode' in response:
            self.repay_mode = response['repay_mode']
        if 'status' in response:
            self.status = response['status']
        if 'term' in response:
            self.term = response['term']
        if 'term_unit' in response:
            self.term_unit = response['term_unit']
        if 'user_name' in response:
            self.user_name = response['user_name']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KbAdvertSubjectVoucher(object):

    def __init__(self):
        self._brand_name = None
        self._city_ids = None
        self._merchant_name = None
        self._purchase_mode = None
        self._voucher_id = None
        self._voucher_name = None
        self._voucher_type = None

    @property
    def brand_name(self):
        return self._brand_name

    @brand_name.setter
    def brand_name(self, value):
        self._brand_name = value
    @property
    def city_ids(self):
        return self._city_ids

    @city_ids.setter
    def city_ids(self, value):
        if isinstance(value, list):
            self._city_ids = list()
            for i in value:
                self._city_ids.append(i)
    @property
    def merchant_name(self):
        return self._merchant_name

    @merchant_name.setter
    def merchant_name(self, value):
        self._merchant_name = value
    @property
    def purchase_mode(self):
        return self._purchase_mode

    @purchase_mode.setter
    def purchase_mode(self, value):
        self._purchase_mode = value
    @property
    def voucher_id(self):
        return self._voucher_id

    @voucher_id.setter
    def voucher_id(self, value):
        self._voucher_id = value
    @property
    def voucher_name(self):
        return self._voucher_name

    @voucher_name.setter
    def voucher_name(self, value):
        self._voucher_name = value
    @property
    def voucher_type(self):
        return self._voucher_type

    @voucher_type.setter
    def voucher_type(self, value):
        self._voucher_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.brand_name:
            if hasattr(self.brand_name, 'to_alipay_dict'):
                params['brand_name'] = self.brand_name.to_alipay_dict()
            else:
                params['brand_name'] = self.brand_name
        if self.city_ids:
            if isinstance(self.city_ids, list):
                for i in range(0, len(self.city_ids)):
                    element = self.city_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.city_ids[i] = element.to_alipay_dict()
            if hasattr(self.city_ids, 'to_alipay_dict'):
                params['city_ids'] = self.city_ids.to_alipay_dict()
            else:
                params['city_ids'] = self.city_ids
        if self.merchant_name:
            if hasattr(self.merchant_name, 'to_alipay_dict'):
                params['merchant_name'] = self.merchant_name.to_alipay_dict()
            else:
                params['merchant_name'] = self.merchant_name
        if self.purchase_mode:
            if hasattr(self.purchase_mode, 'to_alipay_dict'):
                params['purchase_mode'] = self.purchase_mode.to_alipay_dict()
            else:
                params['purchase_mode'] = self.purchase_mode
        if self.voucher_id:
            if hasattr(self.voucher_id, 'to_alipay_dict'):
                params['voucher_id'] = self.voucher_id.to_alipay_dict()
            else:
                params['voucher_id'] = self.voucher_id
        if self.voucher_name:
            if hasattr(self.voucher_name, 'to_alipay_dict'):
                params['voucher_name'] = self.voucher_name.to_alipay_dict()
            else:
                params['voucher_name'] = self.voucher_name
        if self.voucher_type:
            if hasattr(self.voucher_type, 'to_alipay_dict'):
                params['voucher_type'] = self.voucher_type.to_alipay_dict()
            else:
                params['voucher_type'] = self.voucher_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbAdvertSubjectVoucher()
        if 'brand_name' in d:
            o.brand_name = d['brand_name']
        if 'city_ids' in d:
            o.city_ids = d['city_ids']
        if 'merchant_name' in d:
            o.merchant_name = d['merchant_name']
        if 'purchase_mode' in d:
            o.purchase_mode = d['purchase_mode']
        if 'voucher_id' in d:
            o.voucher_id = d['voucher_id']
        if 'voucher_name' in d:
            o.voucher_name = d['voucher_name']
        if 'voucher_type' in d:
            o.voucher_type = d['voucher_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ExtendMedicalCard import ExtendMedicalCard


class AlipayCommerceMedicalCardQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceMedicalCardQueryResponse, self).__init__()
        self._agreement_no = None
        self._bind_status = None
        self._buyer_logon_id = None
        self._buyer_user_id = None
        self._card_org_name = None
        self._card_org_no = None
        self._city = None
        self._extend_cards = None
        self._extend_params = None
        self._gmt_sign = None
        self._medical_card_id = None
        self._medical_card_no = None
        self._medical_card_type = None
        self._other_user_logon_id = None
        self._other_user_status = None
        self._out_user_card_no = None
        self._out_user_name = None
        self._sign_status = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def bind_status(self):
        return self._bind_status

    @bind_status.setter
    def bind_status(self, value):
        self._bind_status = value
    @property
    def buyer_logon_id(self):
        return self._buyer_logon_id

    @buyer_logon_id.setter
    def buyer_logon_id(self, value):
        self._buyer_logon_id = value
    @property
    def buyer_user_id(self):
        return self._buyer_user_id

    @buyer_user_id.setter
    def buyer_user_id(self, value):
        self._buyer_user_id = value
    @property
    def card_org_name(self):
        return self._card_org_name

    @card_org_name.setter
    def card_org_name(self, value):
        self._card_org_name = value
    @property
    def card_org_no(self):
        return self._card_org_no

    @card_org_no.setter
    def card_org_no(self, value):
        self._card_org_no = value
    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def extend_cards(self):
        return self._extend_cards

    @extend_cards.setter
    def extend_cards(self, value):
        if isinstance(value, list):
            self._extend_cards = list()
            for i in value:
                if isinstance(i, ExtendMedicalCard):
                    self._extend_cards.append(i)
                else:
                    self._extend_cards.append(ExtendMedicalCard.from_alipay_dict(i))
    @property
    def extend_params(self):
        return self._extend_params

    @extend_params.setter
    def extend_params(self, value):
        self._extend_params = value
    @property
    def gmt_sign(self):
        return self._gmt_sign

    @gmt_sign.setter
    def gmt_sign(self, value):
        self._gmt_sign = value
    @property
    def medical_card_id(self):
        return self._medical_card_id

    @medical_card_id.setter
    def medical_card_id(self, value):
        self._medical_card_id = value
    @property
    def medical_card_no(self):
        return self._medical_card_no

    @medical_card_no.setter
    def medical_card_no(self, value):
        self._medical_card_no = value
    @property
    def medical_card_type(self):
        return self._medical_card_type

    @medical_card_type.setter
    def medical_card_type(self, value):
        self._medical_card_type = value
    @property
    def other_user_logon_id(self):
        return self._other_user_logon_id

    @other_user_logon_id.setter
    def other_user_logon_id(self, value):
        self._other_user_logon_id = value
    @property
    def other_user_status(self):
        return self._other_user_status

    @other_user_status.setter
    def other_user_status(self, value):
        self._other_user_status = value
    @property
    def out_user_card_no(self):
        return self._out_user_card_no

    @out_user_card_no.setter
    def out_user_card_no(self, value):
        self._out_user_card_no = value
    @property
    def out_user_name(self):
        return self._out_user_name

    @out_user_name.setter
    def out_user_name(self, value):
        self._out_user_name = value
    @property
    def sign_status(self):
        return self._sign_status

    @sign_status.setter
    def sign_status(self, value):
        self._sign_status = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceMedicalCardQueryResponse, self).parse_response_content(response_content)
        if 'agreement_no' in response:
            self.agreement_no = response['agreement_no']
        if 'bind_status' in response:
            self.bind_status = response['bind_status']
        if 'buyer_logon_id' in response:
            self.buyer_logon_id = response['buyer_logon_id']
        if 'buyer_user_id' in response:
            self.buyer_user_id = response['buyer_user_id']
        if 'card_org_name' in response:
            self.card_org_name = response['card_org_name']
        if 'card_org_no' in response:
            self.card_org_no = response['card_org_no']
        if 'city' in response:
            self.city = response['city']
        if 'extend_cards' in response:
            self.extend_cards = response['extend_cards']
        if 'extend_params' in response:
            self.extend_params = response['extend_params']
        if 'gmt_sign' in response:
            self.gmt_sign = response['gmt_sign']
        if 'medical_card_id' in response:
            self.medical_card_id = response['medical_card_id']
        if 'medical_card_no' in response:
            self.medical_card_no = response['medical_card_no']
        if 'medical_card_type' in response:
            self.medical_card_type = response['medical_card_type']
        if 'other_user_logon_id' in response:
            self.other_user_logon_id = response['other_user_logon_id']
        if 'other_user_status' in response:
            self.other_user_status = response['other_user_status']
        if 'out_user_card_no' in response:
            self.out_user_card_no = response['out_user_card_no']
        if 'out_user_name' in response:
            self.out_user_name = response['out_user_name']
        if 'sign_status' in response:
            self.sign_status = response['sign_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TuitionISVChargeDetailDTO import TuitionISVChargeDetailDTO
from alipay.aop.api.domain.TuitionMoneyDTO import TuitionMoneyDTO
from alipay.aop.api.domain.TuitionMoneyDTO import TuitionMoneyDTO
from alipay.aop.api.domain.TuitionMoneyDTO import TuitionMoneyDTO


class TuitionISVAmountInfoDTO(object):

    def __init__(self):
        self._charge_details = None
        self._exchange_rate = None
        self._original_amount = None
        self._target_amount = None
        self._total_amount = None

    @property
    def charge_details(self):
        return self._charge_details

    @charge_details.setter
    def charge_details(self, value):
        if isinstance(value, list):
            self._charge_details = list()
            for i in value:
                if isinstance(i, TuitionISVChargeDetailDTO):
                    self._charge_details.append(i)
                else:
                    self._charge_details.append(TuitionISVChargeDetailDTO.from_alipay_dict(i))
    @property
    def exchange_rate(self):
        return self._exchange_rate

    @exchange_rate.setter
    def exchange_rate(self, value):
        self._exchange_rate = value
    @property
    def original_amount(self):
        return self._original_amount

    @original_amount.setter
    def original_amount(self, value):
        if isinstance(value, TuitionMoneyDTO):
            self._original_amount = value
        else:
            self._original_amount = TuitionMoneyDTO.from_alipay_dict(value)
    @property
    def target_amount(self):
        return self._target_amount

    @target_amount.setter
    def target_amount(self, value):
        if isinstance(value, TuitionMoneyDTO):
            self._target_amount = value
        else:
            self._target_amount = TuitionMoneyDTO.from_alipay_dict(value)
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        if isinstance(value, TuitionMoneyDTO):
            self._total_amount = value
        else:
            self._total_amount = TuitionMoneyDTO.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.charge_details:
            if isinstance(self.charge_details, list):
                for i in range(0, len(self.charge_details)):
                    element = self.charge_details[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.charge_details[i] = element.to_alipay_dict()
            if hasattr(self.charge_details, 'to_alipay_dict'):
                params['charge_details'] = self.charge_details.to_alipay_dict()
            else:
                params['charge_details'] = self.charge_details
        if self.exchange_rate:
            if hasattr(self.exchange_rate, 'to_alipay_dict'):
                params['exchange_rate'] = self.exchange_rate.to_alipay_dict()
            else:
                params['exchange_rate'] = self.exchange_rate
        if self.original_amount:
            if hasattr(self.original_amount, 'to_alipay_dict'):
                params['original_amount'] = self.original_amount.to_alipay_dict()
            else:
                params['original_amount'] = self.original_amount
        if self.target_amount:
            if hasattr(self.target_amount, 'to_alipay_dict'):
                params['target_amount'] = self.target_amount.to_alipay_dict()
            else:
                params['target_amount'] = self.target_amount
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TuitionISVAmountInfoDTO()
        if 'charge_details' in d:
            o.charge_details = d['charge_details']
        if 'exchange_rate' in d:
            o.exchange_rate = d['exchange_rate']
        if 'original_amount' in d:
            o.original_amount = d['original_amount']
        if 'target_amount' in d:
            o.target_amount = d['target_amount']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySocialBaseContentlibStandardvideoauditSendModel(object):

    def __init__(self):
        self._action_type = None
        self._ext_info = None
        self._reason = None
        self._source_publish_date = None
        self._video_id = None
        self._video_length = None
        self._video_publish_type = None
        self._video_size = None
        self._video_tags = None
        self._video_url = None

    @property
    def action_type(self):
        return self._action_type

    @action_type.setter
    def action_type(self, value):
        self._action_type = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def reason(self):
        return self._reason

    @reason.setter
    def reason(self, value):
        self._reason = value
    @property
    def source_publish_date(self):
        return self._source_publish_date

    @source_publish_date.setter
    def source_publish_date(self, value):
        self._source_publish_date = value
    @property
    def video_id(self):
        return self._video_id

    @video_id.setter
    def video_id(self, value):
        self._video_id = value
    @property
    def video_length(self):
        return self._video_length

    @video_length.setter
    def video_length(self, value):
        self._video_length = value
    @property
    def video_publish_type(self):
        return self._video_publish_type

    @video_publish_type.setter
    def video_publish_type(self, value):
        self._video_publish_type = value
    @property
    def video_size(self):
        return self._video_size

    @video_size.setter
    def video_size(self, value):
        self._video_size = value
    @property
    def video_tags(self):
        return self._video_tags

    @video_tags.setter
    def video_tags(self, value):
        self._video_tags = value
    @property
    def video_url(self):
        return self._video_url

    @video_url.setter
    def video_url(self, value):
        self._video_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_type:
            if hasattr(self.action_type, 'to_alipay_dict'):
                params['action_type'] = self.action_type.to_alipay_dict()
            else:
                params['action_type'] = self.action_type
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.reason:
            if hasattr(self.reason, 'to_alipay_dict'):
                params['reason'] = self.reason.to_alipay_dict()
            else:
                params['reason'] = self.reason
        if self.source_publish_date:
            if hasattr(self.source_publish_date, 'to_alipay_dict'):
                params['source_publish_date'] = self.source_publish_date.to_alipay_dict()
            else:
                params['source_publish_date'] = self.source_publish_date
        if self.video_id:
            if hasattr(self.video_id, 'to_alipay_dict'):
                params['video_id'] = self.video_id.to_alipay_dict()
            else:
                params['video_id'] = self.video_id
        if self.video_length:
            if hasattr(self.video_length, 'to_alipay_dict'):
                params['video_length'] = self.video_length.to_alipay_dict()
            else:
                params['video_length'] = self.video_length
        if self.video_publish_type:
            if hasattr(self.video_publish_type, 'to_alipay_dict'):
                params['video_publish_type'] = self.video_publish_type.to_alipay_dict()
            else:
                params['video_publish_type'] = self.video_publish_type
        if self.video_size:
            if hasattr(self.video_size, 'to_alipay_dict'):
                params['video_size'] = self.video_size.to_alipay_dict()
            else:
                params['video_size'] = self.video_size
        if self.video_tags:
            if hasattr(self.video_tags, 'to_alipay_dict'):
                params['video_tags'] = self.video_tags.to_alipay_dict()
            else:
                params['video_tags'] = self.video_tags
        if self.video_url:
            if hasattr(self.video_url, 'to_alipay_dict'):
                params['video_url'] = self.video_url.to_alipay_dict()
            else:
                params['video_url'] = self.video_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySocialBaseContentlibStandardvideoauditSendModel()
        if 'action_type' in d:
            o.action_type = d['action_type']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'reason' in d:
            o.reason = d['reason']
        if 'source_publish_date' in d:
            o.source_publish_date = d['source_publish_date']
        if 'video_id' in d:
            o.video_id = d['video_id']
        if 'video_length' in d:
            o.video_length = d['video_length']
        if 'video_publish_type' in d:
            o.video_publish_type = d['video_publish_type']
        if 'video_size' in d:
            o.video_size = d['video_size']
        if 'video_tags' in d:
            o.video_tags = d['video_tags']
        if 'video_url' in d:
            o.video_url = d['video_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class HelloBikeMarketWord(object):

    def __init__(self):
        self._words = None
        self._words_type = None

    @property
    def words(self):
        return self._words

    @words.setter
    def words(self, value):
        self._words = value
    @property
    def words_type(self):
        return self._words_type

    @words_type.setter
    def words_type(self, value):
        self._words_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.words:
            if hasattr(self.words, 'to_alipay_dict'):
                params['words'] = self.words.to_alipay_dict()
            else:
                params['words'] = self.words
        if self.words_type:
            if hasattr(self.words_type, 'to_alipay_dict'):
                params['words_type'] = self.words_type.to_alipay_dict()
            else:
                params['words_type'] = self.words_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = HelloBikeMarketWord()
        if 'words' in d:
            o.words = d['words']
        if 'words_type' in d:
            o.words_type = d['words_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MerchantOnlineActivityOpenModel import MerchantOnlineActivityOpenModel


class KoubeiMarketingCampaignItemMerchantactivityBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMarketingCampaignItemMerchantactivityBatchqueryResponse, self).__init__()
        self._activities = None

    @property
    def activities(self):
        return self._activities

    @activities.setter
    def activities(self, value):
        if isinstance(value, list):
            self._activities = list()
            for i in value:
                if isinstance(i, MerchantOnlineActivityOpenModel):
                    self._activities.append(i)
                else:
                    self._activities.append(MerchantOnlineActivityOpenModel.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(KoubeiMarketingCampaignItemMerchantactivityBatchqueryResponse, self).parse_response_content(response_content)
        if 'activities' in response:
            self.activities = response['activities']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KbdishDetailInfo(object):

    def __init__(self):
        self._out_dish_id = None
        self._out_sku_id_list = None

    @property
    def out_dish_id(self):
        return self._out_dish_id

    @out_dish_id.setter
    def out_dish_id(self, value):
        self._out_dish_id = value
    @property
    def out_sku_id_list(self):
        return self._out_sku_id_list

    @out_sku_id_list.setter
    def out_sku_id_list(self, value):
        if isinstance(value, list):
            self._out_sku_id_list = list()
            for i in value:
                self._out_sku_id_list.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.out_dish_id:
            if hasattr(self.out_dish_id, 'to_alipay_dict'):
                params['out_dish_id'] = self.out_dish_id.to_alipay_dict()
            else:
                params['out_dish_id'] = self.out_dish_id
        if self.out_sku_id_list:
            if isinstance(self.out_sku_id_list, list):
                for i in range(0, len(self.out_sku_id_list)):
                    element = self.out_sku_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.out_sku_id_list[i] = element.to_alipay_dict()
            if hasattr(self.out_sku_id_list, 'to_alipay_dict'):
                params['out_sku_id_list'] = self.out_sku_id_list.to_alipay_dict()
            else:
                params['out_sku_id_list'] = self.out_sku_id_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbdishDetailInfo()
        if 'out_dish_id' in d:
            o.out_dish_id = d['out_dish_id']
        if 'out_sku_id_list' in d:
            o.out_sku_id_list = d['out_sku_id_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ConversionProperty import ConversionProperty


class ConversionData(object):

    def __init__(self):
        self._biz_no = None
        self._conversion_amount = None
        self._conversion_id = None
        self._conversion_time = None
        self._conversion_type = None
        self._creative_id = None
        self._data_id = None
        self._data_src_type = None
        self._group_id = None
        self._plan_id = None
        self._principal_id = None
        self._principal_tag = None
        self._property_list = None
        self._source = None
        self._target_id = None
        self._target_type = None
        self._uuid = None
        self._uuid_type = None

    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def conversion_amount(self):
        return self._conversion_amount

    @conversion_amount.setter
    def conversion_amount(self, value):
        self._conversion_amount = value
    @property
    def conversion_id(self):
        return self._conversion_id

    @conversion_id.setter
    def conversion_id(self, value):
        self._conversion_id = value
    @property
    def conversion_time(self):
        return self._conversion_time

    @conversion_time.setter
    def conversion_time(self, value):
        self._conversion_time = value
    @property
    def conversion_type(self):
        return self._conversion_type

    @conversion_type.setter
    def conversion_type(self, value):
        self._conversion_type = value
    @property
    def creative_id(self):
        return self._creative_id

    @creative_id.setter
    def creative_id(self, value):
        self._creative_id = value
    @property
    def data_id(self):
        return self._data_id

    @data_id.setter
    def data_id(self, value):
        self._data_id = value
    @property
    def data_src_type(self):
        return self._data_src_type

    @data_src_type.setter
    def data_src_type(self, value):
        self._data_src_type = value
    @property
    def group_id(self):
        return self._group_id

    @group_id.setter
    def group_id(self, value):
        self._group_id = value
    @property
    def plan_id(self):
        return self._plan_id

    @plan_id.setter
    def plan_id(self, value):
        self._plan_id = value
    @property
    def principal_id(self):
        return self._principal_id

    @principal_id.setter
    def principal_id(self, value):
        self._principal_id = value
    @property
    def principal_tag(self):
        return self._principal_tag

    @principal_tag.setter
    def principal_tag(self, value):
        self._principal_tag = value
    @property
    def property_list(self):
        return self._property_list

    @property_list.setter
    def property_list(self, value):
        if isinstance(value, list):
            self._property_list = list()
            for i in value:
                if isinstance(i, ConversionProperty):
                    self._property_list.append(i)
                else:
                    self._property_list.append(ConversionProperty.from_alipay_dict(i))
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def target_id(self):
        return self._target_id

    @target_id.setter
    def target_id(self, value):
        self._target_id = value
    @property
    def target_type(self):
        return self._target_type

    @target_type.setter
    def target_type(self, value):
        self._target_type = value
    @property
    def uuid(self):
        return self._uuid

    @uuid.setter
    def uuid(self, value):
        self._uuid = value
    @property
    def uuid_type(self):
        return self._uuid_type

    @uuid_type.setter
    def uuid_type(self, value):
        self._uuid_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_no:
            if hasattr(self.biz_no, 'to_alipay_dict'):
                params['biz_no'] = self.biz_no.to_alipay_dict()
            else:
                params['biz_no'] = self.biz_no
        if self.conversion_amount:
            if hasattr(self.conversion_amount, 'to_alipay_dict'):
                params['conversion_amount'] = self.conversion_amount.to_alipay_dict()
            else:
                params['conversion_amount'] = self.conversion_amount
        if self.conversion_id:
            if hasattr(self.conversion_id, 'to_alipay_dict'):
                params['conversion_id'] = self.conversion_id.to_alipay_dict()
            else:
                params['conversion_id'] = self.conversion_id
        if self.conversion_time:
            if hasattr(self.conversion_time, 'to_alipay_dict'):
                params['conversion_time'] = self.conversion_time.to_alipay_dict()
            else:
                params['conversion_time'] = self.conversion_time
        if self.conversion_type:
            if hasattr(self.conversion_type, 'to_alipay_dict'):
                params['conversion_type'] = self.conversion_type.to_alipay_dict()
            else:
                params['conversion_type'] = self.conversion_type
        if self.creative_id:
            if hasattr(self.creative_id, 'to_alipay_dict'):
                params['creative_id'] = self.creative_id.to_alipay_dict()
            else:
                params['creative_id'] = self.creative_id
        if self.data_id:
            if hasattr(self.data_id, 'to_alipay_dict'):
                params['data_id'] = self.data_id.to_alipay_dict()
            else:
                params['data_id'] = self.data_id
        if self.data_src_type:
            if hasattr(self.data_src_type, 'to_alipay_dict'):
                params['data_src_type'] = self.data_src_type.to_alipay_dict()
            else:
                params['data_src_type'] = self.data_src_type
        if self.group_id:
            if hasattr(self.group_id, 'to_alipay_dict'):
                params['group_id'] = self.group_id.to_alipay_dict()
            else:
                params['group_id'] = self.group_id
        if self.plan_id:
            if hasattr(self.plan_id, 'to_alipay_dict'):
                params['plan_id'] = self.plan_id.to_alipay_dict()
            else:
                params['plan_id'] = self.plan_id
        if self.principal_id:
            if hasattr(self.principal_id, 'to_alipay_dict'):
                params['principal_id'] = self.principal_id.to_alipay_dict()
            else:
                params['principal_id'] = self.principal_id
        if self.principal_tag:
            if hasattr(self.principal_tag, 'to_alipay_dict'):
                params['principal_tag'] = self.principal_tag.to_alipay_dict()
            else:
                params['principal_tag'] = self.principal_tag
        if self.property_list:
            if isinstance(self.property_list, list):
                for i in range(0, len(self.property_list)):
                    element = self.property_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.property_list[i] = element.to_alipay_dict()
            if hasattr(self.property_list, 'to_alipay_dict'):
                params['property_list'] = self.property_list.to_alipay_dict()
            else:
                params['property_list'] = self.property_list
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.target_id:
            if hasattr(self.target_id, 'to_alipay_dict'):
                params['target_id'] = self.target_id.to_alipay_dict()
            else:
                params['target_id'] = self.target_id
        if self.target_type:
            if hasattr(self.target_type, 'to_alipay_dict'):
                params['target_type'] = self.target_type.to_alipay_dict()
            else:
                params['target_type'] = self.target_type
        if self.uuid:
            if hasattr(self.uuid, 'to_alipay_dict'):
                params['uuid'] = self.uuid.to_alipay_dict()
            else:
                params['uuid'] = self.uuid
        if self.uuid_type:
            if hasattr(self.uuid_type, 'to_alipay_dict'):
                params['uuid_type'] = self.uuid_type.to_alipay_dict()
            else:
                params['uuid_type'] = self.uuid_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ConversionData()
        if 'biz_no' in d:
            o.biz_no = d['biz_no']
        if 'conversion_amount' in d:
            o.conversion_amount = d['conversion_amount']
        if 'conversion_id' in d:
            o.conversion_id = d['conversion_id']
        if 'conversion_time' in d:
            o.conversion_time = d['conversion_time']
        if 'conversion_type' in d:
            o.conversion_type = d['conversion_type']
        if 'creative_id' in d:
            o.creative_id = d['creative_id']
        if 'data_id' in d:
            o.data_id = d['data_id']
        if 'data_src_type' in d:
            o.data_src_type = d['data_src_type']
        if 'group_id' in d:
            o.group_id = d['group_id']
        if 'plan_id' in d:
            o.plan_id = d['plan_id']
        if 'principal_id' in d:
            o.principal_id = d['principal_id']
        if 'principal_tag' in d:
            o.principal_tag = d['principal_tag']
        if 'property_list' in d:
            o.property_list = d['property_list']
        if 'source' in d:
            o.source = d['source']
        if 'target_id' in d:
            o.target_id = d['target_id']
        if 'target_type' in d:
            o.target_type = d['target_type']
        if 'uuid' in d:
            o.uuid = d['uuid']
        if 'uuid_type' in d:
            o.uuid_type = d['uuid_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.GradeDiscountPoint import GradeDiscountPoint


class BenefitGradePoint(object):

    def __init__(self):
        self._benefit_id = None
        self._grade_points = None
        self._original_point = None
        self._own_grades = None

    @property
    def benefit_id(self):
        return self._benefit_id

    @benefit_id.setter
    def benefit_id(self, value):
        self._benefit_id = value
    @property
    def grade_points(self):
        return self._grade_points

    @grade_points.setter
    def grade_points(self, value):
        if isinstance(value, list):
            self._grade_points = list()
            for i in value:
                if isinstance(i, GradeDiscountPoint):
                    self._grade_points.append(i)
                else:
                    self._grade_points.append(GradeDiscountPoint.from_alipay_dict(i))
    @property
    def original_point(self):
        return self._original_point

    @original_point.setter
    def original_point(self, value):
        self._original_point = value
    @property
    def own_grades(self):
        return self._own_grades

    @own_grades.setter
    def own_grades(self, value):
        self._own_grades = value


    def to_alipay_dict(self):
        params = dict()
        if self.benefit_id:
            if hasattr(self.benefit_id, 'to_alipay_dict'):
                params['benefit_id'] = self.benefit_id.to_alipay_dict()
            else:
                params['benefit_id'] = self.benefit_id
        if self.grade_points:
            if isinstance(self.grade_points, list):
                for i in range(0, len(self.grade_points)):
                    element = self.grade_points[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.grade_points[i] = element.to_alipay_dict()
            if hasattr(self.grade_points, 'to_alipay_dict'):
                params['grade_points'] = self.grade_points.to_alipay_dict()
            else:
                params['grade_points'] = self.grade_points
        if self.original_point:
            if hasattr(self.original_point, 'to_alipay_dict'):
                params['original_point'] = self.original_point.to_alipay_dict()
            else:
                params['original_point'] = self.original_point
        if self.own_grades:
            if hasattr(self.own_grades, 'to_alipay_dict'):
                params['own_grades'] = self.own_grades.to_alipay_dict()
            else:
                params['own_grades'] = self.own_grades
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BenefitGradePoint()
        if 'benefit_id' in d:
            o.benefit_id = d['benefit_id']
        if 'grade_points' in d:
            o.grade_points = d['grade_points']
        if 'original_point' in d:
            o.original_point = d['original_point']
        if 'own_grades' in d:
            o.own_grades = d['own_grades']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ArMonthlyStatementBillOpenApiResponse import ArMonthlyStatementBillOpenApiResponse
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi


class AlipayBossFncArbillMonthstatementbillQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBossFncArbillMonthstatementbillQueryResponse, self).__init__()
        self._current_page = None
        self._items_page = None
        self._result_set = None
        self._total_adj_amt = None
        self._total_bill_amt = None
        self._total_inv_amt = None
        self._total_inved_amt = None
        self._total_items = None
        self._total_link_invoice_amt = None
        self._total_pages = None
        self._total_received_amt = None

    @property
    def current_page(self):
        return self._current_page

    @current_page.setter
    def current_page(self, value):
        self._current_page = value
    @property
    def items_page(self):
        return self._items_page

    @items_page.setter
    def items_page(self, value):
        self._items_page = value
    @property
    def result_set(self):
        return self._result_set

    @result_set.setter
    def result_set(self, value):
        if isinstance(value, list):
            self._result_set = list()
            for i in value:
                if isinstance(i, ArMonthlyStatementBillOpenApiResponse):
                    self._result_set.append(i)
                else:
                    self._result_set.append(ArMonthlyStatementBillOpenApiResponse.from_alipay_dict(i))
    @property
    def total_adj_amt(self):
        return self._total_adj_amt

    @total_adj_amt.setter
    def total_adj_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._total_adj_amt = value
        else:
            self._total_adj_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def total_bill_amt(self):
        return self._total_bill_amt

    @total_bill_amt.setter
    def total_bill_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._total_bill_amt = value
        else:
            self._total_bill_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def total_inv_amt(self):
        return self._total_inv_amt

    @total_inv_amt.setter
    def total_inv_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._total_inv_amt = value
        else:
            self._total_inv_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def total_inved_amt(self):
        return self._total_inved_amt

    @total_inved_amt.setter
    def total_inved_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._total_inved_amt = value
        else:
            self._total_inved_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def total_items(self):
        return self._total_items

    @total_items.setter
    def total_items(self, value):
        self._total_items = value
    @property
    def total_link_invoice_amt(self):
        return self._total_link_invoice_amt

    @total_link_invoice_amt.setter
    def total_link_invoice_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._total_link_invoice_amt = value
        else:
            self._total_link_invoice_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def total_pages(self):
        return self._total_pages

    @total_pages.setter
    def total_pages(self, value):
        self._total_pages = value
    @property
    def total_received_amt(self):
        return self._total_received_amt

    @total_received_amt.setter
    def total_received_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._total_received_amt = value
        else:
            self._total_received_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayBossFncArbillMonthstatementbillQueryResponse, self).parse_response_content(response_content)
        if 'current_page' in response:
            self.current_page = response['current_page']
        if 'items_page' in response:
            self.items_page = response['items_page']
        if 'result_set' in response:
            self.result_set = response['result_set']
        if 'total_adj_amt' in response:
            self.total_adj_amt = response['total_adj_amt']
        if 'total_bill_amt' in response:
            self.total_bill_amt = response['total_bill_amt']
        if 'total_inv_amt' in response:
            self.total_inv_amt = response['total_inv_amt']
        if 'total_inved_amt' in response:
            self.total_inved_amt = response['total_inved_amt']
        if 'total_items' in response:
            self.total_items = response['total_items']
        if 'total_link_invoice_amt' in response:
            self.total_link_invoice_amt = response['total_link_invoice_amt']
        if 'total_pages' in response:
            self.total_pages = response['total_pages']
        if 'total_received_amt' in response:
            self.total_received_amt = response['total_received_amt']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class KoubeiCateringTablecodeQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiCateringTablecodeQueryResponse, self).__init__()
        self._code_flag = None
        self._shop_id = None
        self._table_num = None

    @property
    def code_flag(self):
        return self._code_flag

    @code_flag.setter
    def code_flag(self, value):
        self._code_flag = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def table_num(self):
        return self._table_num

    @table_num.setter
    def table_num(self, value):
        self._table_num = value

    def parse_response_content(self, response_content):
        response = super(KoubeiCateringTablecodeQueryResponse, self).parse_response_content(response_content)
        if 'code_flag' in response:
            self.code_flag = response['code_flag']
        if 'shop_id' in response:
            self.shop_id = response['shop_id']
        if 'table_num' in response:
            self.table_num = response['table_num']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntMerchantExpandBenefitRecordQueryModel(object):

    def __init__(self):
        self._benefit_instance_id = None
        self._biz_ext = None
        self._out_user_id = None
        self._page_num = None
        self._page_size = None
        self._status = None
        self._user_id = None

    @property
    def benefit_instance_id(self):
        return self._benefit_instance_id

    @benefit_instance_id.setter
    def benefit_instance_id(self, value):
        self._benefit_instance_id = value
    @property
    def biz_ext(self):
        return self._biz_ext

    @biz_ext.setter
    def biz_ext(self, value):
        self._biz_ext = value
    @property
    def out_user_id(self):
        return self._out_user_id

    @out_user_id.setter
    def out_user_id(self, value):
        self._out_user_id = value
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.benefit_instance_id:
            if hasattr(self.benefit_instance_id, 'to_alipay_dict'):
                params['benefit_instance_id'] = self.benefit_instance_id.to_alipay_dict()
            else:
                params['benefit_instance_id'] = self.benefit_instance_id
        if self.biz_ext:
            if hasattr(self.biz_ext, 'to_alipay_dict'):
                params['biz_ext'] = self.biz_ext.to_alipay_dict()
            else:
                params['biz_ext'] = self.biz_ext
        if self.out_user_id:
            if hasattr(self.out_user_id, 'to_alipay_dict'):
                params['out_user_id'] = self.out_user_id.to_alipay_dict()
            else:
                params['out_user_id'] = self.out_user_id
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandBenefitRecordQueryModel()
        if 'benefit_instance_id' in d:
            o.benefit_instance_id = d['benefit_instance_id']
        if 'biz_ext' in d:
            o.biz_ext = d['biz_ext']
        if 'out_user_id' in d:
            o.out_user_id = d['out_user_id']
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'status' in d:
            o.status = d['status']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMarketingCampaignCashDetailQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingCampaignCashDetailQueryResponse, self).__init__()
        self._camp_status = None
        self._coupon_name = None
        self._crowd_no = None
        self._end_time = None
        self._origin_crowd_no = None
        self._prize_msg = None
        self._prize_type = None
        self._send_amount = None
        self._start_time = None
        self._total_amount = None
        self._total_count = None
        self._total_num = None

    @property
    def camp_status(self):
        return self._camp_status

    @camp_status.setter
    def camp_status(self, value):
        self._camp_status = value
    @property
    def coupon_name(self):
        return self._coupon_name

    @coupon_name.setter
    def coupon_name(self, value):
        self._coupon_name = value
    @property
    def crowd_no(self):
        return self._crowd_no

    @crowd_no.setter
    def crowd_no(self, value):
        self._crowd_no = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def origin_crowd_no(self):
        return self._origin_crowd_no

    @origin_crowd_no.setter
    def origin_crowd_no(self, value):
        self._origin_crowd_no = value
    @property
    def prize_msg(self):
        return self._prize_msg

    @prize_msg.setter
    def prize_msg(self, value):
        self._prize_msg = value
    @property
    def prize_type(self):
        return self._prize_type

    @prize_type.setter
    def prize_type(self, value):
        self._prize_type = value
    @property
    def send_amount(self):
        return self._send_amount

    @send_amount.setter
    def send_amount(self, value):
        self._send_amount = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def total_count(self):
        return self._total_count

    @total_count.setter
    def total_count(self, value):
        self._total_count = value
    @property
    def total_num(self):
        return self._total_num

    @total_num.setter
    def total_num(self, value):
        self._total_num = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingCampaignCashDetailQueryResponse, self).parse_response_content(response_content)
        if 'camp_status' in response:
            self.camp_status = response['camp_status']
        if 'coupon_name' in response:
            self.coupon_name = response['coupon_name']
        if 'crowd_no' in response:
            self.crowd_no = response['crowd_no']
        if 'end_time' in response:
            self.end_time = response['end_time']
        if 'origin_crowd_no' in response:
            self.origin_crowd_no = response['origin_crowd_no']
        if 'prize_msg' in response:
            self.prize_msg = response['prize_msg']
        if 'prize_type' in response:
            self.prize_type = response['prize_type']
        if 'send_amount' in response:
            self.send_amount = response['send_amount']
        if 'start_time' in response:
            self.start_time = response['start_time']
        if 'total_amount' in response:
            self.total_amount = response['total_amount']
        if 'total_count' in response:
            self.total_count = response['total_count']
        if 'total_num' in response:
            self.total_num = response['total_num']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMiniCardData(object):

    def __init__(self):
        self._action_link = None
        self._action_text = None
        self._app_name = None
        self._biz_code = None
        self._card_type = None
        self._coupon_pic = None
        self._edit_text = None
        self._item_pic = None
        self._main_text = None
        self._sub_text = None

    @property
    def action_link(self):
        return self._action_link

    @action_link.setter
    def action_link(self, value):
        self._action_link = value
    @property
    def action_text(self):
        return self._action_text

    @action_text.setter
    def action_text(self, value):
        self._action_text = value
    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def card_type(self):
        return self._card_type

    @card_type.setter
    def card_type(self, value):
        self._card_type = value
    @property
    def coupon_pic(self):
        return self._coupon_pic

    @coupon_pic.setter
    def coupon_pic(self, value):
        self._coupon_pic = value
    @property
    def edit_text(self):
        return self._edit_text

    @edit_text.setter
    def edit_text(self, value):
        self._edit_text = value
    @property
    def item_pic(self):
        return self._item_pic

    @item_pic.setter
    def item_pic(self, value):
        self._item_pic = value
    @property
    def main_text(self):
        return self._main_text

    @main_text.setter
    def main_text(self, value):
        self._main_text = value
    @property
    def sub_text(self):
        return self._sub_text

    @sub_text.setter
    def sub_text(self, value):
        self._sub_text = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_link:
            if hasattr(self.action_link, 'to_alipay_dict'):
                params['action_link'] = self.action_link.to_alipay_dict()
            else:
                params['action_link'] = self.action_link
        if self.action_text:
            if hasattr(self.action_text, 'to_alipay_dict'):
                params['action_text'] = self.action_text.to_alipay_dict()
            else:
                params['action_text'] = self.action_text
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.biz_code:
            if hasattr(self.biz_code, 'to_alipay_dict'):
                params['biz_code'] = self.biz_code.to_alipay_dict()
            else:
                params['biz_code'] = self.biz_code
        if self.card_type:
            if hasattr(self.card_type, 'to_alipay_dict'):
                params['card_type'] = self.card_type.to_alipay_dict()
            else:
                params['card_type'] = self.card_type
        if self.coupon_pic:
            if hasattr(self.coupon_pic, 'to_alipay_dict'):
                params['coupon_pic'] = self.coupon_pic.to_alipay_dict()
            else:
                params['coupon_pic'] = self.coupon_pic
        if self.edit_text:
            if hasattr(self.edit_text, 'to_alipay_dict'):
                params['edit_text'] = self.edit_text.to_alipay_dict()
            else:
                params['edit_text'] = self.edit_text
        if self.item_pic:
            if hasattr(self.item_pic, 'to_alipay_dict'):
                params['item_pic'] = self.item_pic.to_alipay_dict()
            else:
                params['item_pic'] = self.item_pic
        if self.main_text:
            if hasattr(self.main_text, 'to_alipay_dict'):
                params['main_text'] = self.main_text.to_alipay_dict()
            else:
                params['main_text'] = self.main_text
        if self.sub_text:
            if hasattr(self.sub_text, 'to_alipay_dict'):
                params['sub_text'] = self.sub_text.to_alipay_dict()
            else:
                params['sub_text'] = self.sub_text
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMiniCardData()
        if 'action_link' in d:
            o.action_link = d['action_link']
        if 'action_text' in d:
            o.action_text = d['action_text']
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'biz_code' in d:
            o.biz_code = d['biz_code']
        if 'card_type' in d:
            o.card_type = d['card_type']
        if 'coupon_pic' in d:
            o.coupon_pic = d['coupon_pic']
        if 'edit_text' in d:
            o.edit_text = d['edit_text']
        if 'item_pic' in d:
            o.item_pic = d['item_pic']
        if 'main_text' in d:
            o.main_text = d['main_text']
        if 'sub_text' in d:
            o.sub_text = d['sub_text']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CumulateDataDetail(object):

    def __init__(self):
        self._action_type = None
        self._biz_time = None
        self._data_type = None
        self._discount_amount = None
        self._discount_desc = None
        self._out_biz_no = None
        self._refer_out_biz_no = None
        self._sub_data_type = None
        self._task_amount = None
        self._task_desc = None
        self._task_times = None

    @property
    def action_type(self):
        return self._action_type

    @action_type.setter
    def action_type(self, value):
        self._action_type = value
    @property
    def biz_time(self):
        return self._biz_time

    @biz_time.setter
    def biz_time(self, value):
        self._biz_time = value
    @property
    def data_type(self):
        return self._data_type

    @data_type.setter
    def data_type(self, value):
        self._data_type = value
    @property
    def discount_amount(self):
        return self._discount_amount

    @discount_amount.setter
    def discount_amount(self, value):
        self._discount_amount = value
    @property
    def discount_desc(self):
        return self._discount_desc

    @discount_desc.setter
    def discount_desc(self, value):
        self._discount_desc = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def refer_out_biz_no(self):
        return self._refer_out_biz_no

    @refer_out_biz_no.setter
    def refer_out_biz_no(self, value):
        self._refer_out_biz_no = value
    @property
    def sub_data_type(self):
        return self._sub_data_type

    @sub_data_type.setter
    def sub_data_type(self, value):
        self._sub_data_type = value
    @property
    def task_amount(self):
        return self._task_amount

    @task_amount.setter
    def task_amount(self, value):
        self._task_amount = value
    @property
    def task_desc(self):
        return self._task_desc

    @task_desc.setter
    def task_desc(self, value):
        self._task_desc = value
    @property
    def task_times(self):
        return self._task_times

    @task_times.setter
    def task_times(self, value):
        self._task_times = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_type:
            if hasattr(self.action_type, 'to_alipay_dict'):
                params['action_type'] = self.action_type.to_alipay_dict()
            else:
                params['action_type'] = self.action_type
        if self.biz_time:
            if hasattr(self.biz_time, 'to_alipay_dict'):
                params['biz_time'] = self.biz_time.to_alipay_dict()
            else:
                params['biz_time'] = self.biz_time
        if self.data_type:
            if hasattr(self.data_type, 'to_alipay_dict'):
                params['data_type'] = self.data_type.to_alipay_dict()
            else:
                params['data_type'] = self.data_type
        if self.discount_amount:
            if hasattr(self.discount_amount, 'to_alipay_dict'):
                params['discount_amount'] = self.discount_amount.to_alipay_dict()
            else:
                params['discount_amount'] = self.discount_amount
        if self.discount_desc:
            if hasattr(self.discount_desc, 'to_alipay_dict'):
                params['discount_desc'] = self.discount_desc.to_alipay_dict()
            else:
                params['discount_desc'] = self.discount_desc
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.refer_out_biz_no:
            if hasattr(self.refer_out_biz_no, 'to_alipay_dict'):
                params['refer_out_biz_no'] = self.refer_out_biz_no.to_alipay_dict()
            else:
                params['refer_out_biz_no'] = self.refer_out_biz_no
        if self.sub_data_type:
            if hasattr(self.sub_data_type, 'to_alipay_dict'):
                params['sub_data_type'] = self.sub_data_type.to_alipay_dict()
            else:
                params['sub_data_type'] = self.sub_data_type
        if self.task_amount:
            if hasattr(self.task_amount, 'to_alipay_dict'):
                params['task_amount'] = self.task_amount.to_alipay_dict()
            else:
                params['task_amount'] = self.task_amount
        if self.task_desc:
            if hasattr(self.task_desc, 'to_alipay_dict'):
                params['task_desc'] = self.task_desc.to_alipay_dict()
            else:
                params['task_desc'] = self.task_desc
        if self.task_times:
            if hasattr(self.task_times, 'to_alipay_dict'):
                params['task_times'] = self.task_times.to_alipay_dict()
            else:
                params['task_times'] = self.task_times
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CumulateDataDetail()
        if 'action_type' in d:
            o.action_type = d['action_type']
        if 'biz_time' in d:
            o.biz_time = d['biz_time']
        if 'data_type' in d:
            o.data_type = d['data_type']
        if 'discount_amount' in d:
            o.discount_amount = d['discount_amount']
        if 'discount_desc' in d:
            o.discount_desc = d['discount_desc']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'refer_out_biz_no' in d:
            o.refer_out_biz_no = d['refer_out_biz_no']
        if 'sub_data_type' in d:
            o.sub_data_type = d['sub_data_type']
        if 'task_amount' in d:
            o.task_amount = d['task_amount']
        if 'task_desc' in d:
            o.task_desc = d['task_desc']
        if 'task_times' in d:
            o.task_times = d['task_times']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ApeRecContext(object):

    def __init__(self):
        self._city_code = None
        self._client_env = None
        self._current_item_id = None
        self._device_id = None
        self._latitude = None
        self._longitude = None

    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def client_env(self):
        return self._client_env

    @client_env.setter
    def client_env(self, value):
        self._client_env = value
    @property
    def current_item_id(self):
        return self._current_item_id

    @current_item_id.setter
    def current_item_id(self, value):
        self._current_item_id = value
    @property
    def device_id(self):
        return self._device_id

    @device_id.setter
    def device_id(self, value):
        self._device_id = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value


    def to_alipay_dict(self):
        params = dict()
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.client_env:
            if hasattr(self.client_env, 'to_alipay_dict'):
                params['client_env'] = self.client_env.to_alipay_dict()
            else:
                params['client_env'] = self.client_env
        if self.current_item_id:
            if hasattr(self.current_item_id, 'to_alipay_dict'):
                params['current_item_id'] = self.current_item_id.to_alipay_dict()
            else:
                params['current_item_id'] = self.current_item_id
        if self.device_id:
            if hasattr(self.device_id, 'to_alipay_dict'):
                params['device_id'] = self.device_id.to_alipay_dict()
            else:
                params['device_id'] = self.device_id
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ApeRecContext()
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'client_env' in d:
            o.client_env = d['client_env']
        if 'current_item_id' in d:
            o.current_item_id = d['current_item_id']
        if 'device_id' in d:
            o.device_id = d['device_id']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PayUserInfoDTO import PayUserInfoDTO
from alipay.aop.api.domain.PayUserInfoDTO import PayUserInfoDTO


class FdsPayFundItemDTO(object):

    def __init__(self):
        self._amount = None
        self._fund_biz_info = None
        self._fund_item_id = None
        self._gmt_pay = None
        self._memo = None
        self._payee_user_info = None
        self._payer_user_info = None
        self._status = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def fund_biz_info(self):
        return self._fund_biz_info

    @fund_biz_info.setter
    def fund_biz_info(self, value):
        self._fund_biz_info = value
    @property
    def fund_item_id(self):
        return self._fund_item_id

    @fund_item_id.setter
    def fund_item_id(self, value):
        self._fund_item_id = value
    @property
    def gmt_pay(self):
        return self._gmt_pay

    @gmt_pay.setter
    def gmt_pay(self, value):
        self._gmt_pay = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def payee_user_info(self):
        return self._payee_user_info

    @payee_user_info.setter
    def payee_user_info(self, value):
        if isinstance(value, PayUserInfoDTO):
            self._payee_user_info = value
        else:
            self._payee_user_info = PayUserInfoDTO.from_alipay_dict(value)
    @property
    def payer_user_info(self):
        return self._payer_user_info

    @payer_user_info.setter
    def payer_user_info(self, value):
        if isinstance(value, PayUserInfoDTO):
            self._payer_user_info = value
        else:
            self._payer_user_info = PayUserInfoDTO.from_alipay_dict(value)
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.fund_biz_info:
            if hasattr(self.fund_biz_info, 'to_alipay_dict'):
                params['fund_biz_info'] = self.fund_biz_info.to_alipay_dict()
            else:
                params['fund_biz_info'] = self.fund_biz_info
        if self.fund_item_id:
            if hasattr(self.fund_item_id, 'to_alipay_dict'):
                params['fund_item_id'] = self.fund_item_id.to_alipay_dict()
            else:
                params['fund_item_id'] = self.fund_item_id
        if self.gmt_pay:
            if hasattr(self.gmt_pay, 'to_alipay_dict'):
                params['gmt_pay'] = self.gmt_pay.to_alipay_dict()
            else:
                params['gmt_pay'] = self.gmt_pay
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.payee_user_info:
            if hasattr(self.payee_user_info, 'to_alipay_dict'):
                params['payee_user_info'] = self.payee_user_info.to_alipay_dict()
            else:
                params['payee_user_info'] = self.payee_user_info
        if self.payer_user_info:
            if hasattr(self.payer_user_info, 'to_alipay_dict'):
                params['payer_user_info'] = self.payer_user_info.to_alipay_dict()
            else:
                params['payer_user_info'] = self.payer_user_info
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FdsPayFundItemDTO()
        if 'amount' in d:
            o.amount = d['amount']
        if 'fund_biz_info' in d:
            o.fund_biz_info = d['fund_biz_info']
        if 'fund_item_id' in d:
            o.fund_item_id = d['fund_item_id']
        if 'gmt_pay' in d:
            o.gmt_pay = d['gmt_pay']
        if 'memo' in d:
            o.memo = d['memo']
        if 'payee_user_info' in d:
            o.payee_user_info = d['payee_user_info']
        if 'payer_user_info' in d:
            o.payer_user_info = d['payer_user_info']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DeliverySendGuide(object):

    def __init__(self):
        self._delivery_guide_url = None

    @property
    def delivery_guide_url(self):
        return self._delivery_guide_url

    @delivery_guide_url.setter
    def delivery_guide_url(self, value):
        self._delivery_guide_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.delivery_guide_url:
            if hasattr(self.delivery_guide_url, 'to_alipay_dict'):
                params['delivery_guide_url'] = self.delivery_guide_url.to_alipay_dict()
            else:
                params['delivery_guide_url'] = self.delivery_guide_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DeliverySendGuide()
        if 'delivery_guide_url' in d:
            o.delivery_guide_url = d['delivery_guide_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BudgetInfo import BudgetInfo
from alipay.aop.api.domain.GetRuleInfo import GetRuleInfo
from alipay.aop.api.domain.VoucherInfo import VoucherInfo


class AlipayOfflineMarketingVoucherCreateModel(object):

    def __init__(self):
        self._budget_info = None
        self._code_inventory_id = None
        self._ext_info = None
        self._get_rule = None
        self._out_biz_no = None
        self._voucher_info = None

    @property
    def budget_info(self):
        return self._budget_info

    @budget_info.setter
    def budget_info(self, value):
        if isinstance(value, BudgetInfo):
            self._budget_info = value
        else:
            self._budget_info = BudgetInfo.from_alipay_dict(value)
    @property
    def code_inventory_id(self):
        return self._code_inventory_id

    @code_inventory_id.setter
    def code_inventory_id(self, value):
        self._code_inventory_id = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def get_rule(self):
        return self._get_rule

    @get_rule.setter
    def get_rule(self, value):
        if isinstance(value, GetRuleInfo):
            self._get_rule = value
        else:
            self._get_rule = GetRuleInfo.from_alipay_dict(value)
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def voucher_info(self):
        return self._voucher_info

    @voucher_info.setter
    def voucher_info(self, value):
        if isinstance(value, VoucherInfo):
            self._voucher_info = value
        else:
            self._voucher_info = VoucherInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.budget_info:
            if hasattr(self.budget_info, 'to_alipay_dict'):
                params['budget_info'] = self.budget_info.to_alipay_dict()
            else:
                params['budget_info'] = self.budget_info
        if self.code_inventory_id:
            if hasattr(self.code_inventory_id, 'to_alipay_dict'):
                params['code_inventory_id'] = self.code_inventory_id.to_alipay_dict()
            else:
                params['code_inventory_id'] = self.code_inventory_id
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.get_rule:
            if hasattr(self.get_rule, 'to_alipay_dict'):
                params['get_rule'] = self.get_rule.to_alipay_dict()
            else:
                params['get_rule'] = self.get_rule
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.voucher_info:
            if hasattr(self.voucher_info, 'to_alipay_dict'):
                params['voucher_info'] = self.voucher_info.to_alipay_dict()
            else:
                params['voucher_info'] = self.voucher_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOfflineMarketingVoucherCreateModel()
        if 'budget_info' in d:
            o.budget_info = d['budget_info']
        if 'code_inventory_id' in d:
            o.code_inventory_id = d['code_inventory_id']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'get_rule' in d:
            o.get_rule = d['get_rule']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'voucher_info' in d:
            o.voucher_info = d['voucher_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceEducateTrainShopCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceEducateTrainShopCreateResponse, self).__init__()
        self._shop_id = None

    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceEducateTrainShopCreateResponse, self).parse_response_content(response_content)
        if 'shop_id' in response:
            self.shop_id = response['shop_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayTradeVendorpayDevicedataUploadModel(object):

    def __init__(self):
        self._app_package_name = None
        self._ext_info = None
        self._imei = None
        self._imsi = None
        self._mac = None
        self._machine_type = None
        self._phone_sys_version = None
        self._public_key = None
        self._tidsource = None
        self._uuid = None
        self._vendor = None

    @property
    def app_package_name(self):
        return self._app_package_name

    @app_package_name.setter
    def app_package_name(self, value):
        self._app_package_name = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def imei(self):
        return self._imei

    @imei.setter
    def imei(self, value):
        self._imei = value
    @property
    def imsi(self):
        return self._imsi

    @imsi.setter
    def imsi(self, value):
        self._imsi = value
    @property
    def mac(self):
        return self._mac

    @mac.setter
    def mac(self, value):
        self._mac = value
    @property
    def machine_type(self):
        return self._machine_type

    @machine_type.setter
    def machine_type(self, value):
        self._machine_type = value
    @property
    def phone_sys_version(self):
        return self._phone_sys_version

    @phone_sys_version.setter
    def phone_sys_version(self, value):
        self._phone_sys_version = value
    @property
    def public_key(self):
        return self._public_key

    @public_key.setter
    def public_key(self, value):
        self._public_key = value
    @property
    def tidsource(self):
        return self._tidsource

    @tidsource.setter
    def tidsource(self, value):
        self._tidsource = value
    @property
    def uuid(self):
        return self._uuid

    @uuid.setter
    def uuid(self, value):
        self._uuid = value
    @property
    def vendor(self):
        return self._vendor

    @vendor.setter
    def vendor(self, value):
        self._vendor = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_package_name:
            if hasattr(self.app_package_name, 'to_alipay_dict'):
                params['app_package_name'] = self.app_package_name.to_alipay_dict()
            else:
                params['app_package_name'] = self.app_package_name
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.imei:
            if hasattr(self.imei, 'to_alipay_dict'):
                params['imei'] = self.imei.to_alipay_dict()
            else:
                params['imei'] = self.imei
        if self.imsi:
            if hasattr(self.imsi, 'to_alipay_dict'):
                params['imsi'] = self.imsi.to_alipay_dict()
            else:
                params['imsi'] = self.imsi
        if self.mac:
            if hasattr(self.mac, 'to_alipay_dict'):
                params['mac'] = self.mac.to_alipay_dict()
            else:
                params['mac'] = self.mac
        if self.machine_type:
            if hasattr(self.machine_type, 'to_alipay_dict'):
                params['machine_type'] = self.machine_type.to_alipay_dict()
            else:
                params['machine_type'] = self.machine_type
        if self.phone_sys_version:
            if hasattr(self.phone_sys_version, 'to_alipay_dict'):
                params['phone_sys_version'] = self.phone_sys_version.to_alipay_dict()
            else:
                params['phone_sys_version'] = self.phone_sys_version
        if self.public_key:
            if hasattr(self.public_key, 'to_alipay_dict'):
                params['public_key'] = self.public_key.to_alipay_dict()
            else:
                params['public_key'] = self.public_key
        if self.tidsource:
            if hasattr(self.tidsource, 'to_alipay_dict'):
                params['tidsource'] = self.tidsource.to_alipay_dict()
            else:
                params['tidsource'] = self.tidsource
        if self.uuid:
            if hasattr(self.uuid, 'to_alipay_dict'):
                params['uuid'] = self.uuid.to_alipay_dict()
            else:
                params['uuid'] = self.uuid
        if self.vendor:
            if hasattr(self.vendor, 'to_alipay_dict'):
                params['vendor'] = self.vendor.to_alipay_dict()
            else:
                params['vendor'] = self.vendor
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayTradeVendorpayDevicedataUploadModel()
        if 'app_package_name' in d:
            o.app_package_name = d['app_package_name']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'imei' in d:
            o.imei = d['imei']
        if 'imsi' in d:
            o.imsi = d['imsi']
        if 'mac' in d:
            o.mac = d['mac']
        if 'machine_type' in d:
            o.machine_type = d['machine_type']
        if 'phone_sys_version' in d:
            o.phone_sys_version = d['phone_sys_version']
        if 'public_key' in d:
            o.public_key = d['public_key']
        if 'tidsource' in d:
            o.tidsource = d['tidsource']
        if 'uuid' in d:
            o.uuid = d['uuid']
        if 'vendor' in d:
            o.vendor = d['vendor']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.FileItem import FileItem
from alipay.aop.api.constant.ParamConstants import *




class AlipayWeiboPucChargeRequest(object):

    def __init__(self, biz_model=None):
        self._biz_model = biz_model
        self._apd_id = None
        self._cell_id = None
        self._device_info_token = None
        self._exparam = None
        self._imei = None
        self._ip = None
        self._lac_id = None
        self._login_from = None
        self._mac = None
        self._partner_user_id = None
        self._tid = None
        self._token = None
        self._umid = None
        self._wireless_mac = None
        self._version = "1.0"
        self._terminal_type = None
        self._terminal_info = None
        self._prod_code = None
        self._notify_url = None
        self._return_url = None
        self._udf_params = None
        self._need_encrypt = False

    @property
    def biz_model(self):
        return self._biz_model

    @biz_model.setter
    def biz_model(self, value):
        self._biz_model = value

    @property
    def apd_id(self):
        return self._apd_id

    @apd_id.setter
    def apd_id(self, value):
        self._apd_id = value
    @property
    def cell_id(self):
        return self._cell_id

    @cell_id.setter
    def cell_id(self, value):
        self._cell_id = value
    @property
    def device_info_token(self):
        return self._device_info_token

    @device_info_token.setter
    def device_info_token(self, value):
        self._device_info_token = value
    @property
    def exparam(self):
        return self._exparam

    @exparam.setter
    def exparam(self, value):
        self._exparam = value
    @property
    def imei(self):
        return self._imei

    @imei.setter
    def imei(self, value):
        self._imei = value
    @property
    def ip(self):
        return self._ip

    @ip.setter
    def ip(self, value):
        self._ip = value
    @property
    def lac_id(self):
        return self._lac_id

    @lac_id.setter
    def lac_id(self, value):
        self._lac_id = value
    @property
    def login_from(self):
        return self._login_from

    @login_from.setter
    def login_from(self, value):
        self._login_from = value
    @property
    def mac(self):
        return self._mac

    @mac.setter
    def mac(self, value):
        self._mac = value
    @property
    def partner_user_id(self):
        return self._partner_user_id

    @partner_user_id.setter
    def partner_user_id(self, value):
        self._partner_user_id = value
    @property
    def tid(self):
        return self._tid

    @tid.setter
    def tid(self, value):
        self._tid = value
    @property
    def token(self):
        return self._token

    @token.setter
    def token(self, value):
        self._token = value
    @property
    def umid(self):
        return self._umid

    @umid.setter
    def umid(self, value):
        self._umid = value
    @property
    def wireless_mac(self):
        return self._wireless_mac

    @wireless_mac.setter
    def wireless_mac(self, value):
        self._wireless_mac = value


    @property
    def version(self):
        return self._version

    @version.setter
    def version(self, value):
        self._version = value

    @property
    def terminal_type(self):
        return self._terminal_type

    @terminal_type.setter
    def terminal_type(self, value):
        self._terminal_type = value

    @property
    def terminal_info(self):
        return self._terminal_info

    @terminal_info.setter
    def terminal_info(self, value):
        self._terminal_info = value

    @property
    def prod_code(self):
        return self._prod_code

    @prod_code.setter
    def prod_code(self, value):
        self._prod_code = value

    @property
    def notify_url(self):
        return self._notify_url

    @notify_url.setter
    def notify_url(self, value):
        self._notify_url = value

    @property
    def return_url(self):
        return self._return_url

    @return_url.setter
    def return_url(self, value):
        self._return_url = value

    @property
    def udf_params(self):
        return self._udf_params

    @udf_params.setter
    def udf_params(self, value):
        if not isinstance(value, dict):
            return
        self._udf_params = value

    @property
    def need_encrypt(self):
        return self._need_encrypt

    @need_encrypt.setter
    def need_encrypt(self, value):
        self._need_encrypt = value

    def add_other_text_param(self, key, value):
        if not self.udf_params:
            self.udf_params = dict()
        self.udf_params[key] = value

    def get_params(self):
        params = dict()
        params[P_METHOD] = 'alipay.weibo.puc.charge'
        params[P_VERSION] = self.version
        if self.biz_model:
            params[P_BIZ_CONTENT] = json.dumps(obj=self.biz_model.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
        if self.apd_id:
            if hasattr(self.apd_id, 'to_alipay_dict'):
                params['apd_id'] = json.dumps(obj=self.apd_id.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['apd_id'] = self.apd_id
        if self.cell_id:
            if hasattr(self.cell_id, 'to_alipay_dict'):
                params['cell_id'] = json.dumps(obj=self.cell_id.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['cell_id'] = self.cell_id
        if self.device_info_token:
            if hasattr(self.device_info_token, 'to_alipay_dict'):
                params['device_info_token'] = json.dumps(obj=self.device_info_token.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['device_info_token'] = self.device_info_token
        if self.exparam:
            if hasattr(self.exparam, 'to_alipay_dict'):
                params['exparam'] = json.dumps(obj=self.exparam.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['exparam'] = self.exparam
        if self.imei:
            if hasattr(self.imei, 'to_alipay_dict'):
                params['imei'] = json.dumps(obj=self.imei.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['imei'] = self.imei
        if self.ip:
            if hasattr(self.ip, 'to_alipay_dict'):
                params['ip'] = json.dumps(obj=self.ip.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['ip'] = self.ip
        if self.lac_id:
            if hasattr(self.lac_id, 'to_alipay_dict'):
                params['lac_id'] = json.dumps(obj=self.lac_id.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['lac_id'] = self.lac_id
        if self.login_from:
            if hasattr(self.login_from, 'to_alipay_dict'):
                params['login_from'] = json.dumps(obj=self.login_from.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['login_from'] = self.login_from
        if self.mac:
            if hasattr(self.mac, 'to_alipay_dict'):
                params['mac'] = json.dumps(obj=self.mac.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['mac'] = self.mac
        if self.partner_user_id:
            if hasattr(self.partner_user_id, 'to_alipay_dict'):
                params['partner_user_id'] = json.dumps(obj=self.partner_user_id.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['partner_user_id'] = self.partner_user_id
        if self.tid:
            if hasattr(self.tid, 'to_alipay_dict'):
                params['tid'] = json.dumps(obj=self.tid.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['tid'] = self.tid
        if self.token:
            if hasattr(self.token, 'to_alipay_dict'):
                params['token'] = json.dumps(obj=self.token.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['token'] = self.token
        if self.umid:
            if hasattr(self.umid, 'to_alipay_dict'):
                params['umid'] = json.dumps(obj=self.umid.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['umid'] = self.umid
        if self.wireless_mac:
            if hasattr(self.wireless_mac, 'to_alipay_dict'):
                params['wireless_mac'] = json.dumps(obj=self.wireless_mac.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['wireless_mac'] = self.wireless_mac
        if self.terminal_type:
            params['terminal_type'] = self.terminal_type
        if self.terminal_info:
            params['terminal_info'] = self.terminal_info
        if self.prod_code:
            params['prod_code'] = self.prod_code
        if self.notify_url:
            params['notify_url'] = self.notify_url
        if self.return_url:
            params['return_url'] = self.return_url
        if self.udf_params:
            params.update(self.udf_params)
        return params

    def get_multipart_params(self):
        multipart_params = dict()
        return multipart_params



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayAccountClearingcenterPayoffModifyModel(object):

    def __init__(self):
        self._is_high_priority = None
        self._pay_off_no = None

    @property
    def is_high_priority(self):
        return self._is_high_priority

    @is_high_priority.setter
    def is_high_priority(self, value):
        self._is_high_priority = value
    @property
    def pay_off_no(self):
        return self._pay_off_no

    @pay_off_no.setter
    def pay_off_no(self, value):
        self._pay_off_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.is_high_priority:
            if hasattr(self.is_high_priority, 'to_alipay_dict'):
                params['is_high_priority'] = self.is_high_priority.to_alipay_dict()
            else:
                params['is_high_priority'] = self.is_high_priority
        if self.pay_off_no:
            if hasattr(self.pay_off_no, 'to_alipay_dict'):
                params['pay_off_no'] = self.pay_off_no.to_alipay_dict()
            else:
                params['pay_off_no'] = self.pay_off_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayAccountClearingcenterPayoffModifyModel()
        if 'is_high_priority' in d:
            o.is_high_priority = d['is_high_priority']
        if 'pay_off_no' in d:
            o.pay_off_no = d['pay_off_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCreditPeIndustryTradeQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditPeIndustryTradeQueryResponse, self).__init__()
        self._alipay_fund_order_no = None
        self._alipay_out_trade_no = None
        self._amount = None
        self._fund_status = None
        self._fund_type = None
        self._out_fund_no = None
        self._pay_time = None
        self._zm_order_id = None

    @property
    def alipay_fund_order_no(self):
        return self._alipay_fund_order_no

    @alipay_fund_order_no.setter
    def alipay_fund_order_no(self, value):
        self._alipay_fund_order_no = value
    @property
    def alipay_out_trade_no(self):
        return self._alipay_out_trade_no

    @alipay_out_trade_no.setter
    def alipay_out_trade_no(self, value):
        self._alipay_out_trade_no = value
    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def fund_status(self):
        return self._fund_status

    @fund_status.setter
    def fund_status(self, value):
        self._fund_status = value
    @property
    def fund_type(self):
        return self._fund_type

    @fund_type.setter
    def fund_type(self, value):
        self._fund_type = value
    @property
    def out_fund_no(self):
        return self._out_fund_no

    @out_fund_no.setter
    def out_fund_no(self, value):
        self._out_fund_no = value
    @property
    def pay_time(self):
        return self._pay_time

    @pay_time.setter
    def pay_time(self, value):
        self._pay_time = value
    @property
    def zm_order_id(self):
        return self._zm_order_id

    @zm_order_id.setter
    def zm_order_id(self, value):
        self._zm_order_id = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditPeIndustryTradeQueryResponse, self).parse_response_content(response_content)
        if 'alipay_fund_order_no' in response:
            self.alipay_fund_order_no = response['alipay_fund_order_no']
        if 'alipay_out_trade_no' in response:
            self.alipay_out_trade_no = response['alipay_out_trade_no']
        if 'amount' in response:
            self.amount = response['amount']
        if 'fund_status' in response:
            self.fund_status = response['fund_status']
        if 'fund_type' in response:
            self.fund_type = response['fund_type']
        if 'out_fund_no' in response:
            self.out_fund_no = response['out_fund_no']
        if 'pay_time' in response:
            self.pay_time = response['pay_time']
        if 'zm_order_id' in response:
            self.zm_order_id = response['zm_order_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InvoiceItemContent import InvoiceItemContent
from alipay.aop.api.domain.InvoiceTitleModel import InvoiceTitleModel


class InvoiceModelContent(object):

    def __init__(self):
        self._apply_id = None
        self._extend_fields = None
        self._file_download_type = None
        self._file_download_url = None
        self._financial_electronic_type = None
        self._invoice_amount = None
        self._invoice_code = None
        self._invoice_content = None
        self._invoice_date = None
        self._invoice_fake_code = None
        self._invoice_file_data = None
        self._invoice_img_url = None
        self._invoice_no = None
        self._invoice_operator = None
        self._invoice_title = None
        self._invoice_type = None
        self._original_blue_invoice_code = None
        self._original_blue_invoice_no = None
        self._out_biz_no = None
        self._out_invoice_id = None
        self._register_address = None
        self._register_bank_account = None
        self._register_bank_name = None
        self._register_name = None
        self._register_no = None
        self._register_phone_no = None
        self._sum_amount = None
        self._tax_amount = None
        self._tax_type = None
        self._user_id = None

    @property
    def apply_id(self):
        return self._apply_id

    @apply_id.setter
    def apply_id(self, value):
        self._apply_id = value
    @property
    def extend_fields(self):
        return self._extend_fields

    @extend_fields.setter
    def extend_fields(self, value):
        self._extend_fields = value
    @property
    def file_download_type(self):
        return self._file_download_type

    @file_download_type.setter
    def file_download_type(self, value):
        self._file_download_type = value
    @property
    def file_download_url(self):
        return self._file_download_url

    @file_download_url.setter
    def file_download_url(self, value):
        self._file_download_url = value
    @property
    def financial_electronic_type(self):
        return self._financial_electronic_type

    @financial_electronic_type.setter
    def financial_electronic_type(self, value):
        self._financial_electronic_type = value
    @property
    def invoice_amount(self):
        return self._invoice_amount

    @invoice_amount.setter
    def invoice_amount(self, value):
        self._invoice_amount = value
    @property
    def invoice_code(self):
        return self._invoice_code

    @invoice_code.setter
    def invoice_code(self, value):
        self._invoice_code = value
    @property
    def invoice_content(self):
        return self._invoice_content

    @invoice_content.setter
    def invoice_content(self, value):
        if isinstance(value, list):
            self._invoice_content = list()
            for i in value:
                if isinstance(i, InvoiceItemContent):
                    self._invoice_content.append(i)
                else:
                    self._invoice_content.append(InvoiceItemContent.from_alipay_dict(i))
    @property
    def invoice_date(self):
        return self._invoice_date

    @invoice_date.setter
    def invoice_date(self, value):
        self._invoice_date = value
    @property
    def invoice_fake_code(self):
        return self._invoice_fake_code

    @invoice_fake_code.setter
    def invoice_fake_code(self, value):
        self._invoice_fake_code = value
    @property
    def invoice_file_data(self):
        return self._invoice_file_data

    @invoice_file_data.setter
    def invoice_file_data(self, value):
        self._invoice_file_data = value
    @property
    def invoice_img_url(self):
        return self._invoice_img_url

    @invoice_img_url.setter
    def invoice_img_url(self, value):
        self._invoice_img_url = value
    @property
    def invoice_no(self):
        return self._invoice_no

    @invoice_no.setter
    def invoice_no(self, value):
        self._invoice_no = value
    @property
    def invoice_operator(self):
        return self._invoice_operator

    @invoice_operator.setter
    def invoice_operator(self, value):
        self._invoice_operator = value
    @property
    def invoice_title(self):
        return self._invoice_title

    @invoice_title.setter
    def invoice_title(self, value):
        if isinstance(value, InvoiceTitleModel):
            self._invoice_title = value
        else:
            self._invoice_title = InvoiceTitleModel.from_alipay_dict(value)
    @property
    def invoice_type(self):
        return self._invoice_type

    @invoice_type.setter
    def invoice_type(self, value):
        self._invoice_type = value
    @property
    def original_blue_invoice_code(self):
        return self._original_blue_invoice_code

    @original_blue_invoice_code.setter
    def original_blue_invoice_code(self, value):
        self._original_blue_invoice_code = value
    @property
    def original_blue_invoice_no(self):
        return self._original_blue_invoice_no

    @original_blue_invoice_no.setter
    def original_blue_invoice_no(self, value):
        self._original_blue_invoice_no = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def out_invoice_id(self):
        return self._out_invoice_id

    @out_invoice_id.setter
    def out_invoice_id(self, value):
        self._out_invoice_id = value
    @property
    def register_address(self):
        return self._register_address

    @register_address.setter
    def register_address(self, value):
        self._register_address = value
    @property
    def register_bank_account(self):
        return self._register_bank_account

    @register_bank_account.setter
    def register_bank_account(self, value):
        self._register_bank_account = value
    @property
    def register_bank_name(self):
        return self._register_bank_name

    @register_bank_name.setter
    def register_bank_name(self, value):
        self._register_bank_name = value
    @property
    def register_name(self):
        return self._register_name

    @register_name.setter
    def register_name(self, value):
        self._register_name = value
    @property
    def register_no(self):
        return self._register_no

    @register_no.setter
    def register_no(self, value):
        self._register_no = value
    @property
    def register_phone_no(self):
        return self._register_phone_no

    @register_phone_no.setter
    def register_phone_no(self, value):
        self._register_phone_no = value
    @property
    def sum_amount(self):
        return self._sum_amount

    @sum_amount.setter
    def sum_amount(self, value):
        self._sum_amount = value
    @property
    def tax_amount(self):
        return self._tax_amount

    @tax_amount.setter
    def tax_amount(self, value):
        self._tax_amount = value
    @property
    def tax_type(self):
        return self._tax_type

    @tax_type.setter
    def tax_type(self, value):
        self._tax_type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_id:
            if hasattr(self.apply_id, 'to_alipay_dict'):
                params['apply_id'] = self.apply_id.to_alipay_dict()
            else:
                params['apply_id'] = self.apply_id
        if self.extend_fields:
            if hasattr(self.extend_fields, 'to_alipay_dict'):
                params['extend_fields'] = self.extend_fields.to_alipay_dict()
            else:
                params['extend_fields'] = self.extend_fields
        if self.file_download_type:
            if hasattr(self.file_download_type, 'to_alipay_dict'):
                params['file_download_type'] = self.file_download_type.to_alipay_dict()
            else:
                params['file_download_type'] = self.file_download_type
        if self.file_download_url:
            if hasattr(self.file_download_url, 'to_alipay_dict'):
                params['file_download_url'] = self.file_download_url.to_alipay_dict()
            else:
                params['file_download_url'] = self.file_download_url
        if self.financial_electronic_type:
            if hasattr(self.financial_electronic_type, 'to_alipay_dict'):
                params['financial_electronic_type'] = self.financial_electronic_type.to_alipay_dict()
            else:
                params['financial_electronic_type'] = self.financial_electronic_type
        if self.invoice_amount:
            if hasattr(self.invoice_amount, 'to_alipay_dict'):
                params['invoice_amount'] = self.invoice_amount.to_alipay_dict()
            else:
                params['invoice_amount'] = self.invoice_amount
        if self.invoice_code:
            if hasattr(self.invoice_code, 'to_alipay_dict'):
                params['invoice_code'] = self.invoice_code.to_alipay_dict()
            else:
                params['invoice_code'] = self.invoice_code
        if self.invoice_content:
            if isinstance(self.invoice_content, list):
                for i in range(0, len(self.invoice_content)):
                    element = self.invoice_content[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.invoice_content[i] = element.to_alipay_dict()
            if hasattr(self.invoice_content, 'to_alipay_dict'):
                params['invoice_content'] = self.invoice_content.to_alipay_dict()
            else:
                params['invoice_content'] = self.invoice_content
        if self.invoice_date:
            if hasattr(self.invoice_date, 'to_alipay_dict'):
                params['invoice_date'] = self.invoice_date.to_alipay_dict()
            else:
                params['invoice_date'] = self.invoice_date
        if self.invoice_fake_code:
            if hasattr(self.invoice_fake_code, 'to_alipay_dict'):
                params['invoice_fake_code'] = self.invoice_fake_code.to_alipay_dict()
            else:
                params['invoice_fake_code'] = self.invoice_fake_code
        if self.invoice_file_data:
            if hasattr(self.invoice_file_data, 'to_alipay_dict'):
                params['invoice_file_data'] = self.invoice_file_data.to_alipay_dict()
            else:
                params['invoice_file_data'] = self.invoice_file_data
        if self.invoice_img_url:
            if hasattr(self.invoice_img_url, 'to_alipay_dict'):
                params['invoice_img_url'] = self.invoice_img_url.to_alipay_dict()
            else:
                params['invoice_img_url'] = self.invoice_img_url
        if self.invoice_no:
            if hasattr(self.invoice_no, 'to_alipay_dict'):
                params['invoice_no'] = self.invoice_no.to_alipay_dict()
            else:
                params['invoice_no'] = self.invoice_no
        if self.invoice_operator:
            if hasattr(self.invoice_operator, 'to_alipay_dict'):
                params['invoice_operator'] = self.invoice_operator.to_alipay_dict()
            else:
                params['invoice_operator'] = self.invoice_operator
        if self.invoice_title:
            if hasattr(self.invoice_title, 'to_alipay_dict'):
                params['invoice_title'] = self.invoice_title.to_alipay_dict()
            else:
                params['invoice_title'] = self.invoice_title
        if self.invoice_type:
            if hasattr(self.invoice_type, 'to_alipay_dict'):
                params['invoice_type'] = self.invoice_type.to_alipay_dict()
            else:
                params['invoice_type'] = self.invoice_type
        if self.original_blue_invoice_code:
            if hasattr(self.original_blue_invoice_code, 'to_alipay_dict'):
                params['original_blue_invoice_code'] = self.original_blue_invoice_code.to_alipay_dict()
            else:
                params['original_blue_invoice_code'] = self.original_blue_invoice_code
        if self.original_blue_invoice_no:
            if hasattr(self.original_blue_invoice_no, 'to_alipay_dict'):
                params['original_blue_invoice_no'] = self.original_blue_invoice_no.to_alipay_dict()
            else:
                params['original_blue_invoice_no'] = self.original_blue_invoice_no
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.out_invoice_id:
            if hasattr(self.out_invoice_id, 'to_alipay_dict'):
                params['out_invoice_id'] = self.out_invoice_id.to_alipay_dict()
            else:
                params['out_invoice_id'] = self.out_invoice_id
        if self.register_address:
            if hasattr(self.register_address, 'to_alipay_dict'):
                params['register_address'] = self.register_address.to_alipay_dict()
            else:
                params['register_address'] = self.register_address
        if self.register_bank_account:
            if hasattr(self.register_bank_account, 'to_alipay_dict'):
                params['register_bank_account'] = self.register_bank_account.to_alipay_dict()
            else:
                params['register_bank_account'] = self.register_bank_account
        if self.register_bank_name:
            if hasattr(self.register_bank_name, 'to_alipay_dict'):
                params['register_bank_name'] = self.register_bank_name.to_alipay_dict()
            else:
                params['register_bank_name'] = self.register_bank_name
        if self.register_name:
            if hasattr(self.register_name, 'to_alipay_dict'):
                params['register_name'] = self.register_name.to_alipay_dict()
            else:
                params['register_name'] = self.register_name
        if self.register_no:
            if hasattr(self.register_no, 'to_alipay_dict'):
                params['register_no'] = self.register_no.to_alipay_dict()
            else:
                params['register_no'] = self.register_no
        if self.register_phone_no:
            if hasattr(self.register_phone_no, 'to_alipay_dict'):
                params['register_phone_no'] = self.register_phone_no.to_alipay_dict()
            else:
                params['register_phone_no'] = self.register_phone_no
        if self.sum_amount:
            if hasattr(self.sum_amount, 'to_alipay_dict'):
                params['sum_amount'] = self.sum_amount.to_alipay_dict()
            else:
                params['sum_amount'] = self.sum_amount
        if self.tax_amount:
            if hasattr(self.tax_amount, 'to_alipay_dict'):
                params['tax_amount'] = self.tax_amount.to_alipay_dict()
            else:
                params['tax_amount'] = self.tax_amount
        if self.tax_type:
            if hasattr(self.tax_type, 'to_alipay_dict'):
                params['tax_type'] = self.tax_type.to_alipay_dict()
            else:
                params['tax_type'] = self.tax_type
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InvoiceModelContent()
        if 'apply_id' in d:
            o.apply_id = d['apply_id']
        if 'extend_fields' in d:
            o.extend_fields = d['extend_fields']
        if 'file_download_type' in d:
            o.file_download_type = d['file_download_type']
        if 'file_download_url' in d:
            o.file_download_url = d['file_download_url']
        if 'financial_electronic_type' in d:
            o.financial_electronic_type = d['financial_electronic_type']
        if 'invoice_amount' in d:
            o.invoice_amount = d['invoice_amount']
        if 'invoice_code' in d:
            o.invoice_code = d['invoice_code']
        if 'invoice_content' in d:
            o.invoice_content = d['invoice_content']
        if 'invoice_date' in d:
            o.invoice_date = d['invoice_date']
        if 'invoice_fake_code' in d:
            o.invoice_fake_code = d['invoice_fake_code']
        if 'invoice_file_data' in d:
            o.invoice_file_data = d['invoice_file_data']
        if 'invoice_img_url' in d:
            o.invoice_img_url = d['invoice_img_url']
        if 'invoice_no' in d:
            o.invoice_no = d['invoice_no']
        if 'invoice_operator' in d:
            o.invoice_operator = d['invoice_operator']
        if 'invoice_title' in d:
            o.invoice_title = d['invoice_title']
        if 'invoice_type' in d:
            o.invoice_type = d['invoice_type']
        if 'original_blue_invoice_code' in d:
            o.original_blue_invoice_code = d['original_blue_invoice_code']
        if 'original_blue_invoice_no' in d:
            o.original_blue_invoice_no = d['original_blue_invoice_no']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'out_invoice_id' in d:
            o.out_invoice_id = d['out_invoice_id']
        if 'register_address' in d:
            o.register_address = d['register_address']
        if 'register_bank_account' in d:
            o.register_bank_account = d['register_bank_account']
        if 'register_bank_name' in d:
            o.register_bank_name = d['register_bank_name']
        if 'register_name' in d:
            o.register_name = d['register_name']
        if 'register_no' in d:
            o.register_no = d['register_no']
        if 'register_phone_no' in d:
            o.register_phone_no = d['register_phone_no']
        if 'sum_amount' in d:
            o.sum_amount = d['sum_amount']
        if 'tax_amount' in d:
            o.tax_amount = d['tax_amount']
        if 'tax_type' in d:
            o.tax_type = d['tax_type']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GoodsSafetyInventoryVO(object):

    def __init__(self):
        self._gmt_create = None
        self._gmt_modified = None
        self._goods_code = None
        self._historical_daily_sales = None
        self._min_order_num = None
        self._purchase_cycle = None
        self._safety_inventory = None
        self._target_inventory = None
        self._warehouse_code = None

    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def goods_code(self):
        return self._goods_code

    @goods_code.setter
    def goods_code(self, value):
        self._goods_code = value
    @property
    def historical_daily_sales(self):
        return self._historical_daily_sales

    @historical_daily_sales.setter
    def historical_daily_sales(self, value):
        self._historical_daily_sales = value
    @property
    def min_order_num(self):
        return self._min_order_num

    @min_order_num.setter
    def min_order_num(self, value):
        self._min_order_num = value
    @property
    def purchase_cycle(self):
        return self._purchase_cycle

    @purchase_cycle.setter
    def purchase_cycle(self, value):
        self._purchase_cycle = value
    @property
    def safety_inventory(self):
        return self._safety_inventory

    @safety_inventory.setter
    def safety_inventory(self, value):
        self._safety_inventory = value
    @property
    def target_inventory(self):
        return self._target_inventory

    @target_inventory.setter
    def target_inventory(self, value):
        self._target_inventory = value
    @property
    def warehouse_code(self):
        return self._warehouse_code

    @warehouse_code.setter
    def warehouse_code(self, value):
        self._warehouse_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.goods_code:
            if hasattr(self.goods_code, 'to_alipay_dict'):
                params['goods_code'] = self.goods_code.to_alipay_dict()
            else:
                params['goods_code'] = self.goods_code
        if self.historical_daily_sales:
            if hasattr(self.historical_daily_sales, 'to_alipay_dict'):
                params['historical_daily_sales'] = self.historical_daily_sales.to_alipay_dict()
            else:
                params['historical_daily_sales'] = self.historical_daily_sales
        if self.min_order_num:
            if hasattr(self.min_order_num, 'to_alipay_dict'):
                params['min_order_num'] = self.min_order_num.to_alipay_dict()
            else:
                params['min_order_num'] = self.min_order_num
        if self.purchase_cycle:
            if hasattr(self.purchase_cycle, 'to_alipay_dict'):
                params['purchase_cycle'] = self.purchase_cycle.to_alipay_dict()
            else:
                params['purchase_cycle'] = self.purchase_cycle
        if self.safety_inventory:
            if hasattr(self.safety_inventory, 'to_alipay_dict'):
                params['safety_inventory'] = self.safety_inventory.to_alipay_dict()
            else:
                params['safety_inventory'] = self.safety_inventory
        if self.target_inventory:
            if hasattr(self.target_inventory, 'to_alipay_dict'):
                params['target_inventory'] = self.target_inventory.to_alipay_dict()
            else:
                params['target_inventory'] = self.target_inventory
        if self.warehouse_code:
            if hasattr(self.warehouse_code, 'to_alipay_dict'):
                params['warehouse_code'] = self.warehouse_code.to_alipay_dict()
            else:
                params['warehouse_code'] = self.warehouse_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GoodsSafetyInventoryVO()
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'goods_code' in d:
            o.goods_code = d['goods_code']
        if 'historical_daily_sales' in d:
            o.historical_daily_sales = d['historical_daily_sales']
        if 'min_order_num' in d:
            o.min_order_num = d['min_order_num']
        if 'purchase_cycle' in d:
            o.purchase_cycle = d['purchase_cycle']
        if 'safety_inventory' in d:
            o.safety_inventory = d['safety_inventory']
        if 'target_inventory' in d:
            o.target_inventory = d['target_inventory']
        if 'warehouse_code' in d:
            o.warehouse_code = d['warehouse_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class McardStylInfo(object):

    def __init__(self):
        self._background_id = None
        self._bg_color = None
        self._logo_id = None

    @property
    def background_id(self):
        return self._background_id

    @background_id.setter
    def background_id(self, value):
        self._background_id = value
    @property
    def bg_color(self):
        return self._bg_color

    @bg_color.setter
    def bg_color(self, value):
        self._bg_color = value
    @property
    def logo_id(self):
        return self._logo_id

    @logo_id.setter
    def logo_id(self, value):
        self._logo_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.background_id:
            if hasattr(self.background_id, 'to_alipay_dict'):
                params['background_id'] = self.background_id.to_alipay_dict()
            else:
                params['background_id'] = self.background_id
        if self.bg_color:
            if hasattr(self.bg_color, 'to_alipay_dict'):
                params['bg_color'] = self.bg_color.to_alipay_dict()
            else:
                params['bg_color'] = self.bg_color
        if self.logo_id:
            if hasattr(self.logo_id, 'to_alipay_dict'):
                params['logo_id'] = self.logo_id.to_alipay_dict()
            else:
                params['logo_id'] = self.logo_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = McardStylInfo()
        if 'background_id' in d:
            o.background_id = d['background_id']
        if 'bg_color' in d:
            o.bg_color = d['bg_color']
        if 'logo_id' in d:
            o.logo_id = d['logo_id']
        return o


